###################################################
### chunk number 1: options
###################################################

options(width=80)



###################################################
### chunk number 2: loadEarlierRdas
###################################################

rdaList <- c("gse349","gse350","changSuppAndTable")
for(rdaFile in rdaList){
  rdaFullFile <- 
    file.path("RDataObjects",paste(rdaFile,"Rda",sep="."))
  if(file.exists(rdaFullFile)){
    cat("loading ",rdaFullFile, " from cache\n")
    load(rdaFullFile)
  }else{
    cat("building ",rdaFullFile, " from raw data\n")
    Stangle(file.path("RNowebSource",
                      paste("buildRda",rdaFile,"Rnw",sep=".")))
    source(paste("buildRda",rdaFile,"R",sep="."))
  }
}



###################################################
### chunk number 3: bundleGEO
###################################################

if(all(rownames(gse349)==rownames(gse350))){
  geoAll <- cbind(gse349,gse350)
  geoAllInfo <- rbind(gse349Info, gse350Info)
}

geoAll[1:2,]
geoAllInfo



###################################################
### chunk number 4: tryMatchExactly
###################################################

which(geoAll == changSuppQuants[1,1])



###################################################
### chunk number 5: computeGEOCorrs
###################################################

changKeyGenes <- rownames(changSuppQuants)
changGEOCorrs <- cor(changSuppQuants, geoAll[changKeyGenes,])
changGEOCorrs[22:24,1:3]



###################################################
### chunk number 6: plotTopTwoCorrs
###################################################

tempRowMaxes <- apply(changGEOCorrs, 1, max)
tempRowSecondBiggest <- apply(changGEOCorrs, 1, function(x) {
 -sort(-x)[2]})
plot(sort(tempRowMaxes), ylim = c(0.8, 1), 
     ylab = "Corr with Chang Supp Data",
     main = "Best and Next Best Corrs by Row, Sorted by Max")
points(tempRowSecondBiggest[order(tempRowMaxes)], col = "red")
min(tempRowMaxes)
sum(changGEOCorrs >= min(tempRowMaxes))



###################################################
### chunk number 7: plotBestMatches
###################################################

image(1:24, 1:24, changGEOCorrs < 0.988, axes = FALSE, xlab = "",
      ylab = "", asp = 1, main = "Corrs > 0.988 Between Lancet and GEO",
      ylim = c(24.5,0.5))
lines(c(0.5, 24.5), c(14.5, 14.5))
lines(c(11.5, 11.5), c(0.5, 24.5))
rect(0.5, 0.5, 24.5, 24.5)
axis(1, at = 1:24, labels = rownames(changGEOCorrs), las = 2,
     line = -0.5, tick = 0)
axis(2, at = 1:24, labels = colnames(changGEOCorrs), las = 2,
     line = -2.1, tick = 0)
axis(3, at = c(6, 18), labels = c("Sensitive","Resistant"), las = 1,
     line = -1, tick = 0)
mtext(text = c("GSE349 (Res)", "GSE350 (Sen)"), side = 4, 
      at = c(7.5,19.5), line = -1)



###################################################
### chunk number 8: buildChangAll
###################################################

bestPairs <- which(t(changGEOCorrs) > 0.988, arr.ind=TRUE)
bestPairs[1:3,]
bestMapping <- rownames(bestPairs)
names(bestMapping) <- colnames(changSuppQuants)
bestMapping
changAll <- geoAll[,bestMapping]
colnames(changAll) <- colnames(changSuppQuants)
geoAllInfoReorg <- geoAllInfo[bestMapping,]



###################################################
### chunk number 9: checkNewOrder
###################################################

changAllCorWChangSupp <- cor(changAll[changKeyGenes,],changSuppQuants)
sum(changAllCorWChangSupp > 0.988)
sum(diag(changAllCorWChangSupp) > 0.988)



###################################################
### chunk number 10: checkFirstRows
###################################################

geoAllInfoReorg[1:2,]
changSuppClinical[1:2,]
changTable1[1:2,]



###################################################
### chunk number 11: bundleSampleInfo
###################################################

changAllInfo <- 
  data.frame(row.names     = names(bestMapping),
             geoID         = I(bestMapping),
             geoTitle      = geoAllInfoReorg[,"sampleName"],
             status        = geoAllInfoReorg[,"status"],
             pctResidTumor = changSuppClinical[,"PercentResidualTumor"],
             ageInYears    = changTable1[,"Age..years."],
             er            = changTable1[,"Oestrogen..receptor.status"],
             pr            = changTable1[,"Progesterone..receptor.status"],
             her2          = changTable1[,"HER.2"],
             tumorSizeInCm = changTable1[,"Bidimensional.tumour.size..cm."],
             menopause     = changTable1[,"Menopausal.status"],
             ethnicity     = changTable1[,"Ethnic.origin"],
             tumorType     = changTable1[,"Tumour.type"])



###################################################
### chunk number 12: visualInfoCheck
###################################################

changAllInfo



###################################################
### chunk number 13: saveStuff
###################################################

save(changAll, changAllInfo, changKeyGenes, 
     file=file.path("RDataObjects","changAll.Rda"))



###################################################
### chunk number 14: getLocation
###################################################

getwd()



###################################################
### chunk number 15: saveStuff
###################################################



###################################################
### chunk number 16: sessionInfo
###################################################

sessionInfo();



