###################################################
### chunk number 1: options
###################################################

options(width=80)
library(XML)



###################################################
### chunk number 2: readGSE349
###################################################

gse349Dir <- file.path("RawData","GEO","GSE349")
gse349Xml <- xmlTreeParse(file.path(gse349Dir, "GSE349_family.xml"))
gse349Root <- xmlRoot(gse349Xml)
xmlSize(gse349Root)
table(xmlSApply(gse349Root, xmlName))

xmlValue(gse349Root[[which(xmlSApply(gse349Root, xmlName) == 
                           "Series")]][["Summary"]])

idxSample <- which(xmlSApply(gse349Root, xmlName) == "Sample")
gse349Root[[idxSample[1]]]



###################################################
### chunk number 3: grabGSE349Info
###################################################

tempSampleNames <- sapply(idxSample, function(x){
  xmlValue(gse349Root[[x]][["Title"]])})

tempGSMID <- sapply(idxSample, function(x){
  xmlValue(gse349Root[[x]][["Accession"]])})

tempDataFile <- sapply(idxSample, function(x){
  xmlValue(gse349Root[[x]][["Data-Table"]][["External-Data"]])})

tempStatus <- rep("Resistant", length(tempGSMID))

gse349Info <- 
  data.frame(row.names = tempGSMID,
             dataFile = I(tempDataFile),
             sampleName = I(tempSampleNames),
             status = I(tempStatus))

rm(list = ls(pattern = "^temp"))



###################################################
### chunk number 4: correctGSM4913
###################################################

gse349Info["GSM4913","status"] <- "Sensitive"

gse349Info



###################################################
### chunk number 5: readQuants
###################################################

tempTable <- read.table(file.path(gse349Dir, gse349Info[1,"dataFile"]),
                        row.names = 1)
gse349 <- matrix(0, nrow = dim(tempTable)[1], ncol=dim(gse349Info)[1])
rownames(gse349) <- rownames(tempTable)
colnames(gse349) <- rownames(gse349Info)
gse349[,1] <- tempTable[,1]
for(tempSample in 2:dim(gse349Info)[1]){
  tempTable <- 
    read.table(file.path(gse349Dir, gse349Info[tempSample,"dataFile"]),
               row.names = 1)
  if(all(rownames(tempTable) == rownames(gse349))){
    gse349[,tempSample] <- tempTable[,1]
  }
}
rm(list = ls(pattern = "^temp"))



###################################################
### chunk number 6: checkFirstFew
###################################################

dim(gse349)
gse349[1:3,]
apply(gse349,2,min)



###################################################
### chunk number 7: saveStuff
###################################################

save(gse349, gse349Info,
     file=file.path("RDataObjects","gse349.Rda"))



###################################################
### chunk number 8: getLocation
###################################################

getwd()



###################################################
### chunk number 9: saveStuff
###################################################



###################################################
### chunk number 10: sessionInfo
###################################################

sessionInfo();



