###################################################
### chunk number 1: options
###################################################

options(width=80)



###################################################
### chunk number 2: loadWebData
###################################################

## The columns of WEB_DATA_NOVARTIS_ALL.TXT are:
## [1] Probe Set Name,ID,Gene,panelnbr,cellnbr,pname,
## [7] cellname,Signal,Detection,P Value

d1 <- date()
tempTable1 <-
  read.table(unz(file.path("RawData","NCI60",
                           "WEB_DATA_NOVARTIS_ALL.ZIP"),
                 "WEB_DATA_NOVARTIS_ALL.TXT"),
             header=TRUE, sep=",", quote="",
             colClasses=c("character","character","NULL","NULL",
               "NULL","NULL","character","numeric","NULL","NULL"))
d2 <- date()

c(d1,d2)
dim(tempTable1)
nProbes  <- 12626
nSamples <-   180
nProbes * nSamples

tempTable1[1:3,]



###################################################
### chunk number 3: checkOrderSanity
###################################################

probesetNames <- 
  tempTable1[seq(from=1, to=nProbes*nSamples, by=nSamples),
             "Probe.Set.Name"]
all(tempTable1[,"Probe.Set.Name"] == 
    rep(probesetNames,each=nSamples))

replicateSet <- tempTable1[1:nSamples,"ID"]
replicateSet <- 
  substr(replicateSet, nchar(replicateSet), nchar(replicateSet))
cellLine <- tempTable1[1:nSamples,"cellname"]

all(substr(tempTable1[,"ID"],
           nchar(tempTable1[,"ID"]), nchar(tempTable1[,"ID"])) ==
    rep(replicateSet, times=nProbes))
all(tempTable1[,"cellname"] == rep(cellLine, times=nProbes))



###################################################
### chunk number 4: checkWebHooks
###################################################

## The columns of WEB_HOOKS_NOV_GC_ALL.TXT are:
## [1] Probe Set Name,ID,Gene,cellname,pname,panelnbr,
## [7] cellnbr,Signal,Detection,P Value

d3 <- date()
tempTable2 <-
  read.table(unz(file.path("RawData","NCI60",
                           "WEB_HOOKS_NOV_GC_ALL.ZIP"),
                 "WEB_HOOKS_NOV_GC_ALL.TXT"),
             header=TRUE, sep=",", quote="",
             colClasses=c("character","character","NULL","character",
               "NULL","NULL","NULL","numeric","NULL","NULL"))
d4 <- date()

c(d3,d4)
dim(tempTable2)
all(tempTable1 == tempTable2)



###################################################
### chunk number 5: loadNCI60Info
###################################################

nci60Info <- 
  read.table(file.path("RawData","NCI60","nci60Info.csv"),
             sep=",",header=TRUE, 
             colClasses=c("character","character","numeric","numeric"))
nci60Info[1:3,]

which(sort(nci60Info[,"CELL"]) != sort(unique(cellLine)))
sort(nci60Info[,"CELL"])[41]
sort(unique(cellLine))[41]

cellLine[cellLine == "RXF-393"] <- "RXF 393"



###################################################
### chunk number 6: buildQuantificationMatrix
###################################################

tempMatrix <- 
  matrix(tempTable1[,"Signal"], nrow=nProbes, 
         ncol=nSamples, byrow=TRUE)

which(duplicated(probesetNames))
probesetNames[6122:6123]
all(tempMatrix[6122,]==tempMatrix[6123,])

probesetNames <- probesetNames[-6123]
tempMatrix <- tempMatrix[-6123,]

rownames(tempMatrix) <- probesetNames
colnames(tempMatrix) <- paste(cellLine, replicateSet, sep=".")

novartisAll <- tempMatrix
dim(novartisAll)
novartisAll[1:3,1:3]



###################################################
### chunk number 7: buildInfoDataFrame
###################################################

novartisAllInfo <- 
  data.frame(cellLine=I(cellLine),replicateSet=I(replicateSet))
rownames(novartisAllInfo) <- colnames(novartisAll)
novartisAllInfo[1:3,]



###################################################
### chunk number 8: saveRda
###################################################

save(novartisAll, novartisAllInfo,
     file=file.path("RDataObjects","novartisAll.Rda"))



###################################################
### chunk number 9: getLocation
###################################################

getwd()



###################################################
### chunk number 10: saveStuff
###################################################




###################################################
### chunk number 11: sessionInfo
###################################################

sessionInfo();



