###################################################
### chunk number 1: options
###################################################

options(width=80);



###################################################
### chunk number 2: loadCellLinesUsed
###################################################

rdaList <- c("cellLinesUsed")
for(rdaFile in rdaList){
  rdaFullFile <- 
    file.path("RDataObjects",paste(rdaFile,"Rda",sep="."))
  if(file.exists(rdaFullFile)){
    cat("loading ",rdaFullFile, " from cache\n")
    load(rdaFullFile)
  }else{
    cat("building ",rdaFullFile, " from raw data\n")
    Stangle(file.path("RNowebSource",
                      paste("buildRda",rdaFile,"Rnw",sep=".")))
    source(paste("buildRda",rdaFile,"R",sep="."))
  }
}

nscNumbers
nci60CellLines[1:5]
names(cellLinesUsed[["docetaxel"]])
cellLinesUsed[["docetaxel"]][["heatmapPottiNov06"]]



###################################################
### chunk number 3: loadNCI
###################################################

#gi50Files <- 
#  c("GI50_JUL07.BIN.csv","GI50_AUG08.BIN.csv")
#names(gi50Files) <- 
#  paste("gi50", c("jul07","aug08"), sep=".")
#
#tgiFiles <- 
#  c("TGI_JUL07.BIN.csv","TGI_AUG08.BIN.csv")
#names(tgiFiles) <- 
#  paste("tgi", c("jul07","aug08"), sep=".")
#
#lc50Files <- 
#  c("LC50_JUL07.BIN.csv","LC50_AUG08.BIN.csv")
#names(lc50Files) <- 
#  paste("lc50", c("jul07","aug08"), sep=".")

tempGI50Files <- 
  c("GI50_AUG08.BIN.csv")
names(tempGI50Files) <- 
  paste("gi50", c("aug08"), sep=".")

tempTGIFiles <- 
  c("TGI_AUG08.BIN.csv")
names(tempTGIFiles) <- 
  paste("tgi", c("aug08"), sep=".")

tempLC50Files <- 
  c("LC50_AUG08.BIN.csv")
names(tempLC50Files) <- 
  paste("lc50", c("aug08"), sep=".")

tempFiles <- c(tempGI50Files, tempTGIFiles, tempLC50Files)

drugSensitivity <- vector("list", length(tempFiles))
names(drugSensitivity) <- names(tempFiles)

for(tempIndex in 1:length(tempFiles)){
  tempTable <-
    read.table(file.path("RawData","NCI60",
                         tempFiles[tempIndex]), 
               sep=",", header=TRUE)
  tempTable[,"CELL"] <- as.character(tempTable[,"CELL"])
  tempTable[,"CELL"] <- gsub("[[:space:]]+$", "", tempTable[,"CELL"])
  drugSensitivity[[tempIndex]] <- tempTable
}

rm(list=ls(pattern="^temp"))



###################################################
### chunk number 4: quickLook
###################################################

drugSensitivity[["gi50.aug08"]][1:3,]



###################################################
### chunk number 5: extractSensitivityData
###################################################

getSensitivity <- 
  function(drugName, lconc, metric="gi50", version="aug08",
           drugSensitivityList=drugSensitivity,
           nci60CellLineNames=nci60CellLines,
           drugNscNumbers=nscNumbers){

    ## find the metric/version combination, e.g. gi50.aug08.

    dataToGet <- paste(metric, version, sep=".")
    dataToGetIndex <- match(dataToGet, names(drugSensitivityList))
    if(is.na(dataToGetIndex)){
      print(paste("Info for",metric,version,"not found"))
      print(paste("Data is available for:",names(drugSensitivityList)))
      return()
    }
    sensitivityData <- drugSensitivityList[[dataToGetIndex]]

    ## look for the NSC number of the named drug.
    ## a common problem is giving an alternate name for
    ## the drug, such as "adriamycin" instead of "doxorubicin".

    drugNSC <- drugNscNumbers[drugName]
    if(is.na(drugNSC)){
      print(paste("NSC number for",drugName,"not found."))
      print(paste("NSC numbers are available for:", names(drugNscNumbers)))
      return()
    }
    sensitivityData <- 
      sensitivityData[sensitivityData[,"NSC"] == drugNSC,]

    ## look for the drug concentration

    validConcentrations <- 
      unique(sensitivityData[,c("LCONC","TOTN")])
    concentrationIndex <- match(lconc,validConcentrations[,"LCONC"])
    if(is.na(concentrationIndex)){
      print(paste("No data found for an LCONC of",lconc))
      print("Valid concentrations (and numbers of tests) are:")
      print(validConcentrations)
      return()
    }
    sensitivityData <- 
      sensitivityData[sensitivityData[,"LCONC"] == lconc,]

    ## find the canonical lines

    keyRows <- match(nci60CellLineNames,sensitivityData[,"CELL"])

    ## extract whatever value we're looking at

    valueColumn <- grep("^NLOG",names(sensitivityData))
    sensitivityValues <- sensitivityData[keyRows,valueColumn]
    names(sensitivityValues) <- nci60CellLineNames


    list(sensitivityValues=sort(sensitivityValues,na.last=TRUE), 
         drug=drugName,
         nsc=drugNscNumbers[drugName],
         metric=metric,
         version=version,
         lconc=lconc,
         totn=validConcentrations[validConcentrations[,"LCONC"]==lconc,"TOTN"])
  }



###################################################
### chunk number 6: capwords
###################################################

capwords <- function(s, strict = FALSE) {
  cap <- function(s) paste(toupper(substring(s,1,1)),
                           {s <- substring(s,2); if(strict) tolower(s) else s},
                           sep = "", collapse = " " )
  sapply(strsplit(s, split = " "), cap, USE.NAMES = !is.null(names(s)))
}




###################################################
### chunk number 7: plotSensitivity
###################################################

plotSensitivity <- 
  function(sensitivityList, 
           sensitiveLines=NULL, resistantLines=NULL,
           xlab=NULL, ylab=NULL, main=NULL, 
           sensitiveColor=NULL, resistantColor=NULL){
    
    grabWarning <- capture.output(attach(sensitivityList))

    if(is.null(xlab)){
      xlab="Cell Lines"
    }
    drawMtext <- TRUE
    if(!(is.null(ylab))){
      drawMtext <- FALSE
    }
    if(is.null(ylab)){
      ylab=paste("-log10(",toupper(metric),")",sep="")
    }
    if(is.null(main)){
      main=paste(capwords(drug), toupper(metric), sep=" ")
    }
    if(is.null(sensitiveColor)){
      sensitiveColor="gray"
    }
    if(is.null(resistantColor)){
      resistantColor="red"
    }

    plot(sensitivityValues,
         xlab=xlab, ylab=ylab, main=main)
         #xlab="Cell Lines",
         #ylab=paste("-log10(",toupper(metric),")",sep=""),
         #main=paste(capwords(drug), toupper(metric), "LCONC", lconc, 
         #  capwords(version), sep=" ")
         #)
    abline(v=which(is.na(sensitivityValues)),lty="dashed",col="gray")
    if(drawMtext){
      mtext(expression("" %->% Sensitive), side=2, line=3, adj=1)
      mtext(expression(Resistant %<-% ""), side=2, line=3, adj=0)
    }
    if(!is.null(sensitiveLines)){
      sensitiveIndices <- match(sensitiveLines,names(sensitivityValues))
      points(sensitiveIndices, sensitivityValues[sensitiveIndices],
             pch=21,cex=2,bg="gray")
    }
    if(!is.null(resistantLines)){
      resistantIndices <- match(resistantLines,names(sensitivityValues))
      points(resistantIndices, sensitivityValues[resistantIndices],
             pch=24,cex=2,bg="red")
    }
    detach(sensitivityList)
}
    


###################################################
### chunk number 8: plotTwoSensitivities
###################################################

plotTwoSensitivities <- 
  function(xSensitivityList,
           ySensitivityList,
           xlab=NULL, ylab=NULL,
           sensitiveLines=NULL, resistantLines=NULL){
    
    drawXMtext <- TRUE
    if(!(is.null(xlab))){
      drawXMtext <- FALSE
    }
    if(is.null(xlab)){
      xlab=paste(capwords(xSensitivityList$drug), ", ",
        paste("-log10(",toupper(xSensitivityList$metric),")",sep=""),
        sep="")
    }
    drawYMtext <- TRUE
    if(!(is.null(ylab))){
      drawYMtext <- FALSE
    }
    if(is.null(ylab)){
      ylab=paste(capwords(ySensitivityList$drug), ", ",
        paste("-log10(",toupper(ySensitivityList$metric),")",sep=""),
        sep="")
    }
    plot(xSensitivityList$sensitivityValues,
         ySensitivityList$sensitivityValues[
             names(xSensitivityList$sensitivityValues)],
         xlab=xlab,
         ylab=ylab)
    if(drawXMtext){
      mtext(expression("" %->% Sensitive), side=1, line=3, adj=1)
      mtext(expression(Resistant %<-% ""), side=1, line=3, adj=0)
    }
    if(drawYMtext){
      mtext(expression("" %->% Sensitive), side=2, line=3, adj=1)
      mtext(expression(Resistant %<-% ""), side=2, line=3, adj=0)
    }
    if(!is.null(sensitiveLines)){
      points(xSensitivityList$sensitivityValues[sensitiveLines],
             ySensitivityList$sensitivityValues[sensitiveLines],
             pch=21,cex=2,bg="gray")
    }
    if(!is.null(resistantLines)){
      points(xSensitivityList$sensitivityValues[resistantLines],
             ySensitivityList$sensitivityValues[resistantLines],
             pch=24,cex=2,bg="red")
    }
  }





###################################################
### chunk number 9: listDoceSources
###################################################

names(cellLinesUsed[["docetaxel"]])



###################################################
### chunk number 10: listDoceConcentrations
###################################################

getSensitivity("docetaxel",0,"gi50")



###################################################
### chunk number 11: plotDoceGI50
###################################################

temp <- getSensitivity("docetaxel",-4,"gi50")
plotSensitivity(temp,
    sensitiveLines=
        cellLinesUsed[["docetaxel"]][["listPotti06CorrAug08"]][["Sensitive"]],
    resistantLines=
        cellLinesUsed[["docetaxel"]][["listPotti06CorrAug08"]][["Resistant"]])
legend(x=0,y=8,legend=c("Sensitive","Resistant"),
       pch=c(21,24),pt.bg=c("gray","red"),pt.cex=2)



###################################################
### chunk number 12: plotDoceTGI
###################################################

temp <- getSensitivity("docetaxel",-4,"tgi")
plotSensitivity(temp,
    sensitiveLines=
        cellLinesUsed[["docetaxel"]][["listPotti06CorrAug08"]][["Sensitive"]],
    resistantLines=
        cellLinesUsed[["docetaxel"]][["listPotti06CorrAug08"]][["Resistant"]])
legend(x=0,y=8,legend=c("Sensitive","Resistant"),
       pch=c(21,24),pt.bg=c("gray","red"),pt.cex=2)



###################################################
### chunk number 13: plotDoceLC50
###################################################

temp <- getSensitivity("docetaxel",-4,"lc50")
plotSensitivity(temp,
    sensitiveLines=
        cellLinesUsed[["docetaxel"]][["listPotti06CorrAug08"]][["Sensitive"]],
    resistantLines=
        cellLinesUsed[["docetaxel"]][["listPotti06CorrAug08"]][["Resistant"]])
legend(x=0,y=8,legend=c("Sensitive","Resistant"),
       pch=c(21,24),pt.bg=c("gray","red"),pt.cex=2)



###################################################
### chunk number 14: plotDoceTGIandLC50
###################################################

tempTGI  <- getSensitivity("docetaxel",-4,"tgi")
tempLC50 <- getSensitivity("docetaxel",-4,"lc50")

plotTwoSensitivities(tempTGI, tempLC50,
  sensitiveLines=
    cellLinesUsed[["docetaxel"]][["listPotti06CorrAug08"]][["Sensitive"]],
  resistantLines=
    cellLinesUsed[["docetaxel"]][["listPotti06CorrAug08"]][["Resistant"]])
title(main="Docetaxel TGI and LC50")



###################################################
### chunk number 15: nullCOLO205
###################################################

tempLC50[["sensitivityValues"]][["COLO 205"]] <- NA



###################################################
### chunk number 16: plotDoceTGIandLC50noCOLO205
###################################################

plotTwoSensitivities(tempTGI, tempLC50,
  sensitiveLines=
    cellLinesUsed[["docetaxel"]][["listPotti06CorrAug08"]][["Sensitive"]],
  resistantLines=
    cellLinesUsed[["docetaxel"]][["listPotti06CorrAug08"]][["Resistant"]])
title(main="Docetaxel TGI and LC50, COLO 205 Omitted")



###################################################
### chunk number 17: checkResistantDoce
###################################################

tempDoce <- 
  data.frame(tgi=tempTGI$sensitivityValues,
             lc50=tempLC50$sensitivityValues[
                      names(tempTGI$sensitivityValues)],
             status=sensitivityMatrix[
                      names(tempTGI$sensitivityValues),6])
rownames(tempDoce) <- names(tempTGI$sensitivityValues)
tempDoce[1:10,]



###################################################
### chunk number 18: checkDoxoConcentrations
###################################################

temp <- getSensitivity("doxorubicin",0,"tgi")



###################################################
### chunk number 19: plotDoxoGI50
###################################################

temp <- getSensitivity("doxorubicin",-4.6,"gi50")
plotSensitivity(temp,
    sensitiveLines=
        cellLinesUsed[["doxorubicin"]][["listPotti06CorrAug08"]][["Sensitive"]],
    resistantLines=
        cellLinesUsed[["doxorubicin"]][["listPotti06CorrAug08"]][["Resistant"]])



###################################################
### chunk number 20: plotDoxoTGI
###################################################

temp <- getSensitivity("doxorubicin",-4.6,"tgi")
plotSensitivity(temp,
    sensitiveLines=
        cellLinesUsed[["doxorubicin"]][["listPotti06CorrAug08"]][["Sensitive"]],
    resistantLines=
        cellLinesUsed[["doxorubicin"]][["listPotti06CorrAug08"]][["Resistant"]])



###################################################
### chunk number 21: plotDoxoLC50
###################################################

temp <- getSensitivity("doxorubicin",-4.6,"lc50")
plotSensitivity(temp,
    sensitiveLines=
        cellLinesUsed[["doxorubicin"]][["listPotti06CorrAug08"]][["Sensitive"]],
    resistantLines=
        cellLinesUsed[["doxorubicin"]][["listPotti06CorrAug08"]][["Resistant"]])



###################################################
### chunk number 22: plotDoxoTGIandLC50
###################################################

tempTGI  <- getSensitivity("doxorubicin",-4.6,"tgi")
tempLC50 <- getSensitivity("doxorubicin",-4.6,"lc50")

plotTwoSensitivities(tempTGI, tempLC50,
  sensitiveLines=
    cellLinesUsed[["doxorubicin"]][["listPotti06CorrAug08"]][["Sensitive"]],
  resistantLines=
    cellLinesUsed[["doxorubicin"]][["listPotti06CorrAug08"]][["Resistant"]])
title(main="Doxorubicin TGI and LC50")



###################################################
### chunk number 23: getTaxolConcs
###################################################

temp <- getSensitivity("paclitaxel",0,"gi50")



###################################################
### chunk number 24: plotTaxolGI50
###################################################

temp <- getSensitivity("paclitaxel",-4.6,"gi50")

par(mfrow=c(1,2))

plotSensitivity(temp,
    sensitiveLines=
        cellLinesUsed[["paclitaxel"]][["heatmapPottiNov06"]][["Sensitive"]],
    resistantLines=
        cellLinesUsed[["paclitaxel"]][["heatmapPottiNov06"]][["Resistant"]])

plotSensitivity(temp,
    sensitiveLines=
        cellLinesUsed[["paclitaxel"]][["listPotti06CorrAug08"]][["Sensitive"]],
    resistantLines=
        cellLinesUsed[["paclitaxel"]][["listPotti06CorrAug08"]][["Resistant"]])

par(mfrow=c(1,1))



###################################################
### chunk number 25: plotTaxolTGIandLC50
###################################################

par(mfrow=c(1,2))

temp <- getSensitivity("paclitaxel",-4.6,"tgi")

plotSensitivity(temp,
    sensitiveLines=
        cellLinesUsed[["paclitaxel"]][["listPotti06CorrAug08"]][["Sensitive"]],
    resistantLines=
        cellLinesUsed[["paclitaxel"]][["listPotti06CorrAug08"]][["Resistant"]])

temp <- getSensitivity("paclitaxel",-4.6,"lc50")

plotSensitivity(temp,
    sensitiveLines=
        cellLinesUsed[["paclitaxel"]][["listPotti06CorrAug08"]][["Sensitive"]],
    resistantLines=
        cellLinesUsed[["paclitaxel"]][["listPotti06CorrAug08"]][["Resistant"]])

par(mfrow=c(1,1))



###################################################
### chunk number 26: plotTaxolTGIvsLC50
###################################################

tempTGI  <- getSensitivity("paclitaxel",-4.6,"tgi")
tempLC50 <- getSensitivity("paclitaxel",-4.6,"lc50")

plotTwoSensitivities(tempTGI, tempLC50,
  sensitiveLines=
    cellLinesUsed[["paclitaxel"]][["listPotti06CorrAug08"]][["Sensitive"]],
  resistantLines=
    cellLinesUsed[["paclitaxel"]][["listPotti06CorrAug08"]][["Resistant"]])
title(main="Paclitaxel TGI and LC50")



###################################################
### chunk number 27: checkFUConcentrations
###################################################

temp <- getSensitivity("fluorouracil",0,"gi50")



###################################################
### chunk number 28: plotFUGI50s
###################################################

temp <- getSensitivity("fluorouracil",-2.6,"gi50")
plotSensitivity(temp,
    sensitiveLines=
       cellLinesUsed[["fluorouracil"]][["listPotti06CorrAug08"]][["Sensitive"]],
    resistantLines=
       cellLinesUsed[["fluorouracil"]][["listPotti06CorrAug08"]][["Resistant"]])



###################################################
### chunk number 29: plotFUTGIandLC50
###################################################

par(mfrow=c(1,2))

temp <- getSensitivity("fluorouracil",-2.6,"tgi")

plotSensitivity(temp,
    sensitiveLines=
       cellLinesUsed[["fluorouracil"]][["listPotti06CorrAug08"]][["Sensitive"]],
    resistantLines=
       cellLinesUsed[["fluorouracil"]][["listPotti06CorrAug08"]][["Resistant"]])

temp <- getSensitivity("fluorouracil",-2.6,"lc50")

plotSensitivity(temp,
    sensitiveLines=
       cellLinesUsed[["fluorouracil"]][["listPotti06CorrAug08"]][["Sensitive"]],
    resistantLines=
       cellLinesUsed[["fluorouracil"]][["listPotti06CorrAug08"]][["Resistant"]])

par(mfrow=c(1,1))



###################################################
### chunk number 30: plotFUTGIvsLC50
###################################################

tempTGI  <- getSensitivity("fluorouracil",-2.6,"tgi")
tempLC50 <- getSensitivity("fluorouracil",-2.6,"lc50")

plotTwoSensitivities(tempTGI, tempLC50,
  sensitiveLines=
    cellLinesUsed[["fluorouracil"]][["listPotti06CorrAug08"]][["Sensitive"]],
  resistantLines=
    cellLinesUsed[["fluorouracil"]][["listPotti06CorrAug08"]][["Resistant"]])
title(main="Fluorouracil TGI and LC50")



###################################################
### chunk number 31: getTopoConcentrations
###################################################

temp <- getSensitivity("topotecan",0,"gi50")



###################################################
### chunk number 32: plotTopoGI50s
###################################################

temp <- getSensitivity("topotecan",-3.9,"gi50")

par(mfrow=c(1,2))

plotSensitivity(temp,
    sensitiveLines=
        cellLinesUsed[["topotecan"]][["heatmapPottiNov06"]][["Sensitive"]],
    resistantLines=
        cellLinesUsed[["topotecan"]][["heatmapPottiNov06"]][["Resistant"]])

plotSensitivity(temp,
    sensitiveLines=
        cellLinesUsed[["topotecan"]][["listPotti06CorrAug08"]][["Sensitive"]],
    resistantLines=
        cellLinesUsed[["topotecan"]][["listPotti06CorrAug08"]][["Resistant"]])

par(mfrow=c(1,1))



###################################################
### chunk number 33: plotTopoTGIandLC50
###################################################

par(mfrow=c(1,2))

temp <- getSensitivity("topotecan",-3.9,"tgi")

plotSensitivity(temp,
    sensitiveLines=
        cellLinesUsed[["topotecan"]][["listPotti06CorrAug08"]][["Sensitive"]],
    resistantLines=
        cellLinesUsed[["topotecan"]][["listPotti06CorrAug08"]][["Resistant"]])

temp <- getSensitivity("topotecan",-3.9,"lc50")

plotSensitivity(temp,
    sensitiveLines=
        cellLinesUsed[["topotecan"]][["listPotti06CorrAug08"]][["Sensitive"]],
    resistantLines=
        cellLinesUsed[["topotecan"]][["listPotti06CorrAug08"]][["Resistant"]])

par(mfrow=c(1,1))



###################################################
### chunk number 34: plotTopoTGIvsLC50
###################################################

tempTGI  <- getSensitivity("topotecan",-3.9,"tgi")
tempLC50 <- getSensitivity("topotecan",-3.9,"lc50")

plotTwoSensitivities(tempTGI, tempLC50,
  sensitiveLines=
    cellLinesUsed[["topotecan"]][["listPotti06CorrAug08"]][["Sensitive"]],
  resistantLines=
    cellLinesUsed[["topotecan"]][["listPotti06CorrAug08"]][["Resistant"]])
title(main="Topotecan TGI and LC50")



###################################################
### chunk number 35: checkEtopoConcentrations
###################################################

temp <- getSensitivity("etoposide",0,"tgi")



###################################################
### chunk number 36: plotEtopoGI50s
###################################################

temp <- getSensitivity("etoposide",-3.0,"gi50")

par(mfrow=c(1,2))

plotSensitivity(temp,
    sensitiveLines=
        cellLinesUsed[["etoposide"]][["heatmapPottiNov06"]][["Sensitive"]],
    resistantLines=
        cellLinesUsed[["etoposide"]][["heatmapPottiNov06"]][["Resistant"]])

plotSensitivity(temp,
    sensitiveLines=
        cellLinesUsed[["etoposide"]][["listPotti06CorrAug08"]][["Sensitive"]],
    resistantLines=
        cellLinesUsed[["etoposide"]][["listPotti06CorrAug08"]][["Resistant"]])

par(mfrow=c(1,1))



###################################################
### chunk number 37: plotEtopoTGIandLC50
###################################################

par(mfrow=c(1,2))

temp <- getSensitivity("etoposide",-3.0,"tgi")

plotSensitivity(temp,
    sensitiveLines=
        cellLinesUsed[["etoposide"]][["listPotti06CorrAug08"]][["Sensitive"]],
    resistantLines=
        cellLinesUsed[["etoposide"]][["listPotti06CorrAug08"]][["Resistant"]])

temp <- getSensitivity("etoposide",-3.0,"lc50")

plotSensitivity(temp,
    sensitiveLines=
        cellLinesUsed[["etoposide"]][["listPotti06CorrAug08"]][["Sensitive"]],
    resistantLines=
        cellLinesUsed[["etoposide"]][["listPotti06CorrAug08"]][["Resistant"]])

par(mfrow=c(1,1))



###################################################
### chunk number 38: plotEtopoTGIvsLC50
###################################################

tempTGI  <- getSensitivity("etoposide",-3.0,"tgi")
tempLC50 <- getSensitivity("etoposide",-3.0,"lc50")

plotTwoSensitivities(tempTGI, tempLC50,
  sensitiveLines=
    cellLinesUsed[["etoposide"]][["listPotti06CorrAug08"]][["Sensitive"]],
  resistantLines=
    cellLinesUsed[["etoposide"]][["listPotti06CorrAug08"]][["Resistant"]])
title(main="Etoposide TGI and LC50")



###################################################
### chunk number 39: checkCyclophosphamideConcentrations
###################################################

temp <- getSensitivity("cyclophosphamide",0,"tgi")



###################################################
### chunk number 40: plotCyclophosphamideGI50s
###################################################

temp <- getSensitivity("cyclophosphamide",-3.6,"gi50")

par(mfrow=c(1,2))

plotSensitivity(temp,
    sensitiveLines=
        cellLinesUsed[["cyclophosphamide"]][["geneListPotti06CorrNov07"]][["Sensitive"]],
    resistantLines=
        cellLinesUsed[["cyclophosphamide"]][["geneListPotti06CorrNov07"]][["Resistant"]])

plotSensitivity(temp,
    sensitiveLines=
        cellLinesUsed[["cyclophosphamide"]][["listPotti06CorrAug08"]][["Sensitive"]],
    resistantLines=
        cellLinesUsed[["cyclophosphamide"]][["listPotti06CorrAug08"]][["Resistant"]])

par(mfrow=c(1,1))



###################################################
### chunk number 41: plotCyclophosphamideTGIandLC50Values
###################################################

par(mfrow=c(1,2))

temp <- getSensitivity("cyclophosphamide",-3.6,"tgi")

plotSensitivity(temp,
  sensitiveLines=
   cellLinesUsed[["cyclophosphamide"]][["listPotti06CorrAug08"]][["Sensitive"]],
  resistantLines=
   cellLinesUsed[["cyclophosphamide"]][["listPotti06CorrAug08"]][["Resistant"]])

temp <- getSensitivity("cyclophosphamide",-3.6,"lc50")

plotSensitivity(temp,
  sensitiveLines=
   cellLinesUsed[["cyclophosphamide"]][["listPotti06CorrAug08"]][["Sensitive"]],
  resistantLines=
   cellLinesUsed[["cyclophosphamide"]][["listPotti06CorrAug08"]][["Resistant"]])

par(mfrow=c(1,1))



###################################################
### chunk number 42: checkPemetrexedConcentrations
###################################################

temp <- getSensitivity("pemetrexed",0,"gi50")



###################################################
### chunk number 43: plotPemetrexedGI50s
###################################################

temp <- getSensitivity("pemetrexed",-4.0,"gi50")

plotSensitivity(temp,
    sensitiveLines=
        cellLinesUsed[["pemetrexed"]][["heatmapHsuOct07"]][["Sensitive"]],
    resistantLines=
        cellLinesUsed[["pemetrexed"]][["heatmapHsuOct07"]][["Resistant"]])



###################################################
### chunk number 44: plotPemetrexedTGIandLC50
###################################################

par(mfrow=c(1,2))

temp <- getSensitivity("pemetrexed",-4.0,"tgi")

plotSensitivity(temp,
    sensitiveLines=
        cellLinesUsed[["pemetrexed"]][["heatmapHsuOct07"]][["Sensitive"]],
    resistantLines=
        cellLinesUsed[["pemetrexed"]][["heatmapHsuOct07"]][["Resistant"]])

temp <- getSensitivity("pemetrexed",-4.0,"lc50")

plotSensitivity(temp,
    sensitiveLines=
        cellLinesUsed[["pemetrexed"]][["heatmapHsuOct07"]][["Sensitive"]],
    resistantLines=
        cellLinesUsed[["pemetrexed"]][["heatmapHsuOct07"]][["Resistant"]])

par(mfrow=c(1,1))



###################################################
### chunk number 45: getCisplatinConcentrations
###################################################

temp <- getSensitivity("cisplatin",0,"gi50")



###################################################
### chunk number 46: plotCisplatinGI50
###################################################

par(mfrow=c(2,2))

temp <- getSensitivity("cisplatin",-3.3,"gi50")
plotSensitivity(temp,ylab="-log10(GI50)")

temp <- getSensitivity("cisplatin",-3.3,"tgi")
plotSensitivity(temp,ylab="-log10(TGI)")

temp <- getSensitivity("cisplatin",-3.3,"lc50")
plotSensitivity(temp,ylab="-log10(LC50)")

par(mfrow=c(1,1))



###################################################
### chunk number 47: checkTemozolomideConcentrations
###################################################

temp <- getSensitivity("temozolomide",0,"gi50")



###################################################
### chunk number 48: plotTemozolomideGI50s
###################################################

temp <- getSensitivity("temozolomide",-4.0,"gi50")

plotSensitivity(temp)



###################################################
### chunk number 49: plotTemozolomideTGIandLC50
###################################################

par(mfrow=c(1,2))

temp <- getSensitivity("temozolomide",-4.0,"tgi")
plotSensitivity(temp)

temp <- getSensitivity("temozolomide",-4.0,"lc50")
plotSensitivity(temp)

par(mfrow=c(1,1))



###################################################
### chunk number 50: checkDaunorubicinConcentrations
###################################################

temp <- getSensitivity("daunorubicin",0,"gi50")



###################################################
### chunk number 51: plotDoxoDauno
###################################################

par(mfrow=c(2,2))

tempDoxGI50  <- getSensitivity("doxorubicin",-4.6,"gi50")
tempDaunoGI50 <- getSensitivity("daunorubicin",-4.3,"gi50")

plotTwoSensitivities(tempDoxGI50, tempDaunoGI50,
  sensitiveLines=
    cellLinesUsed[["doxorubicin"]][["listPotti06CorrAug08"]][["Sensitive"]],
  resistantLines=
    cellLinesUsed[["doxorubicin"]][["listPotti06CorrAug08"]][["Resistant"]],
  xlab="Doxorubicin", ylab="Daunorubicin")
title(main="GI50")


tempDoxTGI  <- getSensitivity("doxorubicin",-4.6,"tgi")
tempDaunoTGI <- getSensitivity("daunorubicin",-4.3,"tgi")

plotTwoSensitivities(tempDoxTGI, tempDaunoTGI,
  sensitiveLines=
    cellLinesUsed[["doxorubicin"]][["listPotti06CorrAug08"]][["Sensitive"]],
  resistantLines=
    cellLinesUsed[["doxorubicin"]][["listPotti06CorrAug08"]][["Resistant"]],
  xlab="Doxorubicin", ylab="Daunorubicin")
title(main="TGI")

tempDoxLC50  <- getSensitivity("doxorubicin",-4.6,"lc50")
tempDaunoLC50 <- getSensitivity("daunorubicin",-4.3,"lc50")

plotTwoSensitivities(tempDoxLC50, tempDaunoLC50,
  sensitiveLines=
    cellLinesUsed[["doxorubicin"]][["listPotti06CorrAug08"]][["Sensitive"]],
  resistantLines=
    cellLinesUsed[["doxorubicin"]][["listPotti06CorrAug08"]][["Resistant"]],
  xlab="Doxorubicin", ylab="Daunorubicin")
title(main="LC50")

par(mfrow=c(1,1))



###################################################
### chunk number 52: checkEpirubicinConcentrations
###################################################

temp <- getSensitivity("epirubicin",0,"gi50")



###################################################
### chunk number 53: plotDoxoEpi
###################################################

par(mfrow=c(2,2))

tempDoxGI50  <- getSensitivity("doxorubicin",-4.6,"gi50")
tempEpiGI50 <- getSensitivity("epirubicin",-4,"gi50")

plotTwoSensitivities(tempDoxGI50, tempEpiGI50,
  sensitiveLines=
    cellLinesUsed[["doxorubicin"]][["listPotti06CorrAug08"]][["Sensitive"]],
  resistantLines=
    cellLinesUsed[["doxorubicin"]][["listPotti06CorrAug08"]][["Resistant"]],
  xlab="Doxorubicin", ylab="Epirubicin")
title(main="GI50")


tempDoxTGI  <- getSensitivity("doxorubicin",-4.6,"tgi")
tempEpiTGI <- getSensitivity("epirubicin",-4,"tgi")

plotTwoSensitivities(tempDoxTGI, tempEpiTGI,
  sensitiveLines=
    cellLinesUsed[["doxorubicin"]][["listPotti06CorrAug08"]][["Sensitive"]],
  resistantLines=
    cellLinesUsed[["doxorubicin"]][["listPotti06CorrAug08"]][["Resistant"]],
  xlab="Doxorubicin", ylab="Epirubicin")
title(main="TGI")

tempDoxLC50  <- getSensitivity("doxorubicin",-4.6,"lc50")
tempEpiLC50 <- getSensitivity("epirubicin",-4,"lc50")

plotTwoSensitivities(tempDoxLC50, tempEpiLC50,
  sensitiveLines=
    cellLinesUsed[["doxorubicin"]][["listPotti06CorrAug08"]][["Sensitive"]],
  resistantLines=
    cellLinesUsed[["doxorubicin"]][["listPotti06CorrAug08"]][["Resistant"]],
  xlab="Doxorubicin", ylab="Epirubicin")
title(main="LC50")

par(mfrow=c(1,1))




###################################################
### chunk number 54: checkVincristineConcentrations
###################################################

temp <- getSensitivity("vincristine",0,"gi50")



###################################################
### chunk number 55: plotDoxoVinc
###################################################

par(mfrow=c(2,2))

tempDoxGI50  <- getSensitivity("doxorubicin",-4.6,"gi50")
tempVincGI50 <- getSensitivity("vincristine",-3,"gi50")

plotTwoSensitivities(tempDoxGI50, tempVincGI50,
  sensitiveLines=
    cellLinesUsed[["doxorubicin"]][["listPotti06CorrAug08"]][["Sensitive"]],
  resistantLines=
    cellLinesUsed[["doxorubicin"]][["listPotti06CorrAug08"]][["Resistant"]],
  xlab="Doxorubicin", ylab="Vincristine")
title(main="GI50")

tempDoxTGI  <- getSensitivity("doxorubicin",-4.6,"tgi")
tempVincTGI <- getSensitivity("vincristine",-3,"tgi")

plotTwoSensitivities(tempDoxTGI, tempVincTGI,
  sensitiveLines=
    cellLinesUsed[["doxorubicin"]][["listPotti06CorrAug08"]][["Sensitive"]],
  resistantLines=
    cellLinesUsed[["doxorubicin"]][["listPotti06CorrAug08"]][["Resistant"]],
  xlab="Doxorubicin", ylab="Vincristine")
title(main="TGI")

tempDoxLC50  <- getSensitivity("doxorubicin",-4.6,"lc50")
tempVincLC50 <- getSensitivity("vincristine",-3,"lc50")

plotTwoSensitivities(tempDoxLC50, tempVincLC50,
  sensitiveLines=
    cellLinesUsed[["doxorubicin"]][["listPotti06CorrAug08"]][["Sensitive"]],
  resistantLines=
    cellLinesUsed[["doxorubicin"]][["listPotti06CorrAug08"]][["Resistant"]],
  xlab="Doxorubicin", ylab="Vincristine")
title(main="LC50")

par(mfrow=c(1,1))



###################################################
### chunk number 56: plotVincOnly
###################################################

par(mfrow=c(2,2))

tempVincGI50 <- getSensitivity("vincristine",-3,"gi50")

plotSensitivity(tempVincGI50,
  sensitiveLines=
    cellLinesUsed[["doxorubicin"]][["listPotti06CorrAug08"]][["Sensitive"]],
  resistantLines=
    cellLinesUsed[["doxorubicin"]][["listPotti06CorrAug08"]][["Resistant"]],
  ylab="-log10(GI50)")

tempVincTGI <- getSensitivity("vincristine",-3,"tgi")

plotSensitivity(tempVincTGI,
  sensitiveLines=
    cellLinesUsed[["doxorubicin"]][["listPotti06CorrAug08"]][["Sensitive"]],
  resistantLines=
    cellLinesUsed[["doxorubicin"]][["listPotti06CorrAug08"]][["Resistant"]],
  ylab="-log10(TGI)")

tempVincLC50 <- getSensitivity("vincristine",-3,"lc50")

plotSensitivity(tempVincLC50,
  sensitiveLines=
    cellLinesUsed[["doxorubicin"]][["listPotti06CorrAug08"]][["Sensitive"]],
  resistantLines=
    cellLinesUsed[["doxorubicin"]][["listPotti06CorrAug08"]][["Resistant"]],
  ylab="-log10(LC50)")

par(mfrow=c(1,1))



###################################################
### chunk number 57: plotPemUsingCycGI50s
###################################################

temp <- getSensitivity("pemetrexed",-4,"gi50")

plotSensitivity(temp,
  sensitiveLines=
   cellLinesUsed[["cyclophosphamide"]][["listPotti06CorrAug08"]][["Sensitive"]],
  resistantLines=
   cellLinesUsed[["cyclophosphamide"]][["listPotti06CorrAug08"]][["Resistant"]])

points(match(c("EKVX","SW-620","SN12C","SK-MEL-28"),
             names(temp$sensitivityValues)),
       temp$sensitivityValues[c("EKVX","SW-620","SN12C","SK-MEL-28")],
       pch=24,bg="pink",cex=2)

legend(x=0, y=8, 
       legend=c("Sens Cyclophosphamide","Res Cyclophosphamide",
         "Res Cyc (Gene List)"),
       pch=c(21,24,24), pt.bg=c("gray","red","pink"),pt.cex=2)



###################################################
### chunk number 58: plotBigFigure eval=FALSE
###################################################
## 
## par(mfrow=c(3,2))
## 
## ## Row 1, Column 1 -- Docetaxel GI50 values. 
## 
## temp <- getSensitivity("docetaxel",-4,"gi50")
## plotSensitivity(temp,
##     sensitiveLines=
##         cellLinesUsed[["docetaxel"]][["listPotti06CorrAug08"]][["Sensitive"]],
##     resistantLines=
##         cellLinesUsed[["docetaxel"]][["listPotti06CorrAug08"]][["Resistant"]],
##     ylab="-log10(GI50)")
## #legend(x=0,y=8,legend=c("Sensitive","Resistant"),
## #       pch=c(21,24),pt.bg=c("gray","red"),pt.cex=2)
## legend(x=30,y=6,legend=c("Sensitive","Resistant"),
##        pch=c(21,24),pt.bg=c("gray","red"),pt.cex=2)
## 
## ## Row 1, Column 2 -- Doxorubicin vs Vincristine, TGI
## 
## tempDoxTGI  <- getSensitivity("doxorubicin",-4.6,"tgi")
## tempVincTGI <- getSensitivity("vincristine",-3,"tgi")
## 
## plotTwoSensitivities(tempDoxTGI, tempVincTGI,
##   sensitiveLines=
##     cellLinesUsed[["doxorubicin"]][["listPotti06CorrAug08"]][["Sensitive"]],
##   resistantLines=
##     cellLinesUsed[["doxorubicin"]][["listPotti06CorrAug08"]][["Resistant"]],
##   xlab="Doxorubicin", ylab="Vincristine")
## title(main="Doxorubicin vs Vincristine, TGI")
## 
## ## Row 2, Column 1 -- temozolomide GI50s
## 
## temp <- getSensitivity("temozolomide",-4.0,"gi50")
## plotSensitivity(temp,ylab="-log10(GI50)")
## 
## ## Row 2, Column 2 -- cyclophosphamide GI50s
## 
## temp <- getSensitivity("cyclophosphamide",-3.6,"gi50")
## plotSensitivity(temp,
##   sensitiveLines=
##     cellLinesUsed[["cyclophosphamide"]][["geneListPotti06CorrNov07"]][["Sensitive"]],
##   resistantLines=
##     cellLinesUsed[["cyclophosphamide"]][["geneListPotti06CorrNov07"]][["Resistant"]],
##   ylab="-log10(GI50)")
## 
## ## Row 3, Column 1 -- pemetrexed GI50s, pemetrexed cell lines
## 
## temp <- getSensitivity("pemetrexed",-4.0,"gi50")
## plotSensitivity(temp,
##     sensitiveLines=
##         cellLinesUsed[["pemetrexed"]][["heatmapHsuOct07"]][["Sensitive"]],
##     resistantLines=
##         cellLinesUsed[["pemetrexed"]][["heatmapHsuOct07"]][["Resistant"]],
##     ylab="-log10(GI50)")
## legend(x=0, y=8, 
##        legend=c("Sens Pemetrexed","Res Pemetrexed"),
##        pch=c(21,24), pt.bg=c("gray","red"),pt.cex=2)
## 
## ## Row 3, Column 2 -- pemetrexed GI50s, cyclophosphamide cell lines
## 
## temp <- getSensitivity("pemetrexed",-4,"gi50")
## plotSensitivity(temp,
##   sensitiveLines=
##    cellLinesUsed[["cyclophosphamide"]][["listPotti06CorrAug08"]][["Sensitive"]],
##   resistantLines=
##    cellLinesUsed[["cyclophosphamide"]][["listPotti06CorrAug08"]][["Resistant"]],
##   ylab="-log10(GI50)")
## points(match(c("EKVX","SW-620","SN12C","SK-MEL-28"),
##              names(temp$sensitivityValues)),
##        temp$sensitivityValues[c("EKVX","SW-620","SN12C","SK-MEL-28")],
##        pch=24,bg="pink",cex=2)
## legend(x=0, y=8, 
##        legend=c("Sens Cyclophosphamide","Res Cyclophosphamide",
##          "Res Cyc (Gene List)"),
##        pch=c(21,24,24), pt.bg=c("gray","red","pink"),pt.cex=2)
## 
## 
## par(mfrow=c(1,1))
## 


###################################################
### chunk number 59: reallyPlotBig
###################################################

pdf(file="Figures/bigFigure.pdf",height=12, width=9)

par(mfrow=c(3,2))

## Row 1, Column 1 -- Docetaxel GI50 values. 

temp <- getSensitivity("docetaxel",-4,"gi50")
plotSensitivity(temp,
    sensitiveLines=
        cellLinesUsed[["docetaxel"]][["listPotti06CorrAug08"]][["Sensitive"]],
    resistantLines=
        cellLinesUsed[["docetaxel"]][["listPotti06CorrAug08"]][["Resistant"]],
    ylab="-log10(GI50)")
#legend(x=0,y=8,legend=c("Sensitive","Resistant"),
#       pch=c(21,24),pt.bg=c("gray","red"),pt.cex=2)
legend(x=30,y=6,legend=c("Sensitive","Resistant"),
       pch=c(21,24),pt.bg=c("gray","red"),pt.cex=2)

## Row 1, Column 2 -- Doxorubicin vs Vincristine, TGI

tempDoxTGI  <- getSensitivity("doxorubicin",-4.6,"tgi")
tempVincTGI <- getSensitivity("vincristine",-3,"tgi")

plotTwoSensitivities(tempDoxTGI, tempVincTGI,
  sensitiveLines=
    cellLinesUsed[["doxorubicin"]][["listPotti06CorrAug08"]][["Sensitive"]],
  resistantLines=
    cellLinesUsed[["doxorubicin"]][["listPotti06CorrAug08"]][["Resistant"]],
  xlab="Doxorubicin", ylab="Vincristine")
title(main="Doxorubicin vs Vincristine, TGI")

## Row 2, Column 1 -- temozolomide GI50s

temp <- getSensitivity("temozolomide",-4.0,"gi50")
plotSensitivity(temp,ylab="-log10(GI50)")

## Row 2, Column 2 -- cyclophosphamide GI50s

temp <- getSensitivity("cyclophosphamide",-3.6,"gi50")
plotSensitivity(temp,
  sensitiveLines=
    cellLinesUsed[["cyclophosphamide"]][["geneListPotti06CorrNov07"]][["Sensitive"]],
  resistantLines=
    cellLinesUsed[["cyclophosphamide"]][["geneListPotti06CorrNov07"]][["Resistant"]],
  ylab="-log10(GI50)")

## Row 3, Column 1 -- pemetrexed GI50s, pemetrexed cell lines

temp <- getSensitivity("pemetrexed",-4.0,"gi50")
plotSensitivity(temp,
    sensitiveLines=
        cellLinesUsed[["pemetrexed"]][["heatmapHsuOct07"]][["Sensitive"]],
    resistantLines=
        cellLinesUsed[["pemetrexed"]][["heatmapHsuOct07"]][["Resistant"]],
    ylab="-log10(GI50)")
legend(x=0, y=8, 
       legend=c("Sens Pemetrexed","Res Pemetrexed"),
       pch=c(21,24), pt.bg=c("gray","red"),pt.cex=2)

## Row 3, Column 2 -- pemetrexed GI50s, cyclophosphamide cell lines

temp <- getSensitivity("pemetrexed",-4,"gi50")
plotSensitivity(temp,
  sensitiveLines=
   cellLinesUsed[["cyclophosphamide"]][["listPotti06CorrAug08"]][["Sensitive"]],
  resistantLines=
   cellLinesUsed[["cyclophosphamide"]][["listPotti06CorrAug08"]][["Resistant"]],
  ylab="-log10(GI50)")
points(match(c("EKVX","SW-620","SN12C","SK-MEL-28"),
             names(temp$sensitivityValues)),
       temp$sensitivityValues[c("EKVX","SW-620","SN12C","SK-MEL-28")],
       pch=24,bg="pink",cex=2)
legend(x=0, y=8, 
       legend=c("Sens Cyclophosphamide","Res Cyclophosphamide",
         "Res Cyc (Gene List)"),
       pch=c(21,24,24), pt.bg=c("gray","red","pink"),pt.cex=2)


par(mfrow=c(1,1))

dev.off()



###################################################
### chunk number 60: getwd
###################################################

getwd()



###################################################
### chunk number 61: sessionInfo
###################################################

sessionInfo();



