###################################################
### chunk number 1: options
###################################################

options(width=80);



###################################################
### chunk number 2: tableNSCNumbers
###################################################

nscNumbers <- 
  c(628503, # docetaxel
    125973, # paclitaxel
    123127, # doxorubicin
    19893,  # fluorouracil
    609699, # topotecan
    141540, # etoposide
    26271,  # cyclophosphamide
    698037, # pemetrexed
    119875, # cisplatin
    256942, # epirubicin
    82151,  # daunorubicin
    67574,  # vincristine
    362856  # temozolomide
    )
names(nscNumbers) <- 
  c("docetaxel",
    "paclitaxel",
    "doxorubicin",
    "fluorouracil",
    "topotecan",
    "etoposide",
    "cyclophosphamide",
    "pemetrexed",
    "cisplatin",
    "epirubicin",
    "daunorubicin",
    "vincristine",
    "temozolomide"
    )
nscNumbers



###################################################
### chunk number 3: nameTheCellLines
###################################################

nci60CellLines <- 
  c("NCI-H23", "NCI-H522", "A549/ATCC", "EKVX", "NCI-H226", "NCI-H322M",
    "NCI-H460", "HOP-62", "HOP-92", "HT29", "HCC-2998", "HCT-116", 
    "SW-620", "COLO 205", "HCT-15", "KM12", "MCF7", "NCI/ADR-RES",
    "MDA-MB-231/ATCC", "HS 578T", "MDA-MB-435", "BT-549", "T-47D", "OVCAR-3",
    "OVCAR-4", "OVCAR-5", "OVCAR-8", "IGROV1", "SK-OV-3", "CCRF-CEM",
    "K-562", "MOLT-4", "HL-60(TB)", "RPMI-8226", "SR", "UO-31",
    "SN12C", "A498", "CAKI-1", "RXF 393", "786-0", "ACHN",
    "TK-10", "LOX IMVI", "MALME-3M", "SK-MEL-2", "SK-MEL-5", "SK-MEL-28",
    "M14", "UACC-62", "UACC-257", "PC-3", "DU-145", "SNB-19",
    "SNB-75", "U251", "SF-268", "SF-295", "SF-539")



###################################################
### chunk number 4: loadNovAData
###################################################

rdaList <- c("novartisA")
for(rdaFile in rdaList){
  rdaFullFile <- 
    file.path("RDataObjects",paste(rdaFile,"Rda",sep="."))
  if(file.exists(rdaFullFile)){
    cat("loading ",rdaFullFile, " from cache\n")
    load(rdaFullFile)
  }else{
    cat("building ",rdaFullFile, " from raw data\n")
    Stangle(file.path("RNowebSource",
                      paste("buildRda",rdaFile,"Rnw",sep=".")))
    source(paste("buildRda",rdaFile,"R",sep="."))
  }
}

novartisA[1:3,1:3]
all(sort(colnames(novartisA)) == sort(nci60CellLines))



###################################################
### chunk number 5: gyorffyLines
###################################################

gyorffyCellLines <- 
  c("181P", "257P", "A375", "BT20", "C8161", "colo699",
    "Cx2", "Du145", "DV90", "ES2", "FUOV1", "Hep3B",
    "HRT18", "HT29", "mda231", "me43", "MeWo", "OAW42",
    "OVKAR", "R103", "R193", "SKBR3", "SKMel13", "SKMel19",
    "Skov3", "SNU182", "SNU423", "SNU449", "SNU475", "Sw13")



###################################################
### chunk number 6: defineCellLines
###################################################

cellLinesUsed <- vector("list",length(nscNumbers))
names(cellLinesUsed) <- names(nscNumbers)

informationSources <- c("heatmapPottiNov06",
                        "heatmapHsuOct07",
                        "geneListPotti06CorrNov07",
                        "doceDataPotti06CorrNov07",
                        "doxoDataPotti06CorrNov07",
                        "listPotti06CorrNov07",
                        "listBonnefoiDec07",
                        "numbersSalterApr08",
                        "listPotti06CorrAug08",
                        "listBonnefoi07CorrSep08",
                        "numbersRiedelOct08",
                        "heatmapAugustineJan09"
                        )
             
tempLabels <- c("Sensitive", "Resistant")

for(tempIndex1 in 1:length(cellLinesUsed)){

  cellLinesUsed[[tempIndex1]] <- 
    vector("list",length(informationSources))
  names(cellLinesUsed[[tempIndex1]]) <- informationSources

  for(tempIndex2 in 1:length(informationSources)){

    cellLinesUsed[[tempIndex1]][[tempIndex2]] <- 
                  vector("list",length(tempLabels))
    names(cellLinesUsed[[tempIndex1]][[tempIndex2]]) <- tempLabels 

  }
}

rm(list=ls(pattern="^temp"))



###################################################
### chunk number 7: listsFromPotti06Heatmaps
###################################################

cellLinesUsed[["docetaxel"]][["heatmapPottiNov06"]][["Resistant"]] <- 
  c("EKVX","IGROV1","OVCAR-4","786-0","CAKI-1","SN12C","TK-10") ## 7 lines
cellLinesUsed[["docetaxel"]][["heatmapPottiNov06"]][["Sensitive"]] <- 
  c("HL-60(TB)","SF-539","HT29","HOP-62","SK-MEL-2","SK-MEL-5",
    "NCI-H522") ## 7 lines

cellLinesUsed[["paclitaxel"]][["heatmapPottiNov06"]][["Resistant"]] <- 
  c("SF-295","SF-539","HS 578T","MDA-MB-435","COLO 205","HCC-2998",	
    "HT29","OVCAR-3","DU-145") ## 9 lines
cellLinesUsed[["paclitaxel"]][["heatmapPottiNov06"]][["Sensitive"]] <- 
  c("CCRF-CEM","SW-620","A549/ATCC","EKVX","MALME-3M","SK-MEL-28",
    "OVCAR-8","786-0") ## 8 lines

cellLinesUsed[["doxorubicin"]][["heatmapPottiNov06"]][["Resistant"]] <- 
  c("SF-539","SNB-75","MDA-MB-435","NCI-H23","M14","MALME-3M","SK-MEL-2",
    "SK-MEL-28","SK-MEL-5","UACC-62") ## 10 lines
cellLinesUsed[["doxorubicin"]][["heatmapPottiNov06"]][["Sensitive"]] <- 
  c("NCI/ADR-RES","HCT-15","HT29","EKVX","NCI-H322M","IGROV1","OVCAR-3",
    "OVCAR-4","OVCAR-5","OVCAR-8","SK-OV-3","CAKI-1") ## 12 lines

cellLinesUsed[["fluorouracil"]][["heatmapPottiNov06"]][["Resistant"]] <- 
  c("MCF7","COLO 205","HCT-116","NCI-H460","LOX IMVI","SK-MEL-5",
    "A498","UO-31") ## 8 lines
cellLinesUsed[["fluorouracil"]][["heatmapPottiNov06"]][["Sensitive"]] <- 
  c("NCI/ADR-RES","MDA-MB-435","SW-620","EKVX","M14","SN12C",
    "OVCAR-8") ## 7 lines

cellLinesUsed[["topotecan"]][["heatmapPottiNov06"]][["Resistant"]] <- 
  c("SF-539","SNB-75","U251","HS 578T","HOP-62","NCI-H226","NCI-H23",
    "LOX IMVI","OVCAR-8","A498","ACHN","CAKI-1","UO-31") ## 13 lines
cellLinesUsed[["topotecan"]][["heatmapPottiNov06"]][["Sensitive"]] <- 
  c("K-562","RPMI-8226","MDA-MB-435","SK-MEL-5","HCC-2998",	
    "HCT-116","HCT-15","NCI-H322M","SK-MEL-28","COLO 205") ## 10 lines

cellLinesUsed[["etoposide"]][["heatmapPottiNov06"]][["Resistant"]] <- 
  c("SF-539","BT-549","MDA-MB-231/ATCC","NCI/ADR-RES","HOP-62",
    "NCI-H226","SK-MEL-28","UACC-257","786-0") ## 9 lines
cellLinesUsed[["etoposide"]][["heatmapPottiNov06"]][["Sensitive"]] <- 
  c("MCF7","HCC-2998","HCT-15","SW-620","NCI-H322M","PC-3",
    "OVCAR-4","OVCAR-5") ## 8 lines



###################################################
### chunk number 8: cisplatinSignature
###################################################

cellLinesUsed[["cisplatin"]][["heatmapHsuOct07"]][["Resistant"]] <- 
  c("257P", "A375", "C8161", "ES2", "me43", "MeWo", 
    "SKMel19", "SNU423", "Sw13") ## 9 lines
cellLinesUsed[["cisplatin"]][["heatmapHsuOct07"]][["Sensitive"]] <- 
  c("BT20", "DV90", "FUOV1", "OAW42", "OVKAR", "R103") ## 6 lines



###################################################
### chunk number 9: pemetrexedSignature
###################################################

cellLinesUsed[["pemetrexed"]][["heatmapHsuOct07"]][["Resistant"]] <- 
  c("K-562", "MOLT-4", "HL-60(TB)", "MCF7", "HCC-2998", 
    "HCT-116", "NCI-H460", "TK-10") ## 8 lines
cellLinesUsed[["pemetrexed"]][["heatmapHsuOct07"]][["Sensitive"]] <- 
  c("SNB-19", "HS 578T", "MDA-MB-231/ATCC", "MDA-MB-435", 
    "NCI-H226", "M14", "MALME-3M", "SK-MEL-2", 
    "SK-MEL-28", "SN12C") ## 10 lines



###################################################
### chunk number 10: fromGeneListsPotti06Corr07
###################################################
tempDrugs <- c("docetaxel", "paclitaxel", "doxorubicin",      
               "fluorouracil", "topotecan", "etoposide")
for(tempIndex in 1:length(tempDrugs)){ 
  cellLinesUsed[[tempDrugs[tempIndex]]][["geneListPotti06CorrNov07"]] <- 
    cellLinesUsed[[tempDrugs[tempIndex]]][["heatmapPottiNov06"]]
}
cellLinesUsed[["cyclophosphamide"]][["geneListPotti06CorrNov07"]][["Sensitive"]] <-   
  c("K-562","MOLT-4","HL-60(TB)","MCF7","HCC-2998","HCT-116",
    "NCI-H460","TK-10")
cellLinesUsed[["cyclophosphamide"]][["geneListPotti06CorrNov07"]][["Resistant"]] <-   
  c("SNB-19","HS 578T","MDA-MB-231/ATCC","MDA-MB-435",
    "SW-620", "EKVX", "NCI-H226","M14",
    "MALME-3M","SK-MEL-2","SK-MEL-28","SN12C")


###################################################
### chunk number 11: linesFromPotti07List
###################################################

cellLinesUsed[["docetaxel"]][["listPotti06CorrNov07"]][["Resistant"]] <- 
  c("EKVX","IGROV1","OVCAR-4","786-0","CAKI-1","SN12C","TK-10") ## 7 lines
cellLinesUsed[["docetaxel"]][["listPotti06CorrNov07"]][["Sensitive"]] <- 
  c("HL-60(TB)","SF-539","HT29","HOP-62","SK-MEL-2","SK-MEL-5",
    "NCI-H522") ## 7 lines

cellLinesUsed[["paclitaxel"]][["listPotti06CorrNov07"]][["Resistant"]] <- 
  c("SF-295","SF-539","HS 578T","MDA-MB-435","COLO 205","HCC-2998",	
    "HT29","OVCAR-3","NCI-H522") ## 9 lines
cellLinesUsed[["paclitaxel"]][["listPotti06CorrNov07"]][["Sensitive"]] <- 
  c("CCRF-CEM","SW-620","A549/ATCC","EKVX","MALME-3M","SK-MEL-28",
    "OVCAR-8","786-0") ## 8 lines

cellLinesUsed[["doxorubicin"]][["listPotti06CorrNov07"]][["Resistant"]] <- 
  c("SF-539","SNB-75","MDA-MB-435","NCI-H23","M14","MALME-3M","SK-MEL-2",
    "SK-MEL-28","SK-MEL-5","UACC-62") ## 10 lines
cellLinesUsed[["doxorubicin"]][["listPotti06CorrNov07"]][["Sensitive"]] <- 
  c("NCI/ADR-RES","HCT-15","HT29","EKVX","NCI-H322M","IGROV1","OVCAR-3",
    "OVCAR-4","OVCAR-5","OVCAR-8","SK-OV-3","CAKI-1") ## 12 lines

cellLinesUsed[["fluorouracil"]][["listPotti06CorrNov07"]][["Resistant"]] <- 
  c("MCF7","COLO 205","HCT-116","NCI-H460","LOX IMVI","SK-MEL-5",
    "A498","UO-31") ## 8 lines
cellLinesUsed[["fluorouracil"]][["listPotti06CorrNov07"]][["Sensitive"]] <- 
  c("NCI/ADR-RES","MDA-MB-435","SW-620","EKVX","M14","SN12C",
    "OVCAR-8") ## 7 lines

cellLinesUsed[["topotecan"]][["listPotti06CorrNov07"]][["Resistant"]] <- 
  c("SF-539","SNB-75","U251","HS 578T","HOP-62","NCI-H226","NCI-H23",
    "LOX IMVI","OVCAR-8","A498","ACHN","CAKI-1","UO-31") ## 13 lines
cellLinesUsed[["topotecan"]][["listPotti06CorrNov07"]][["Sensitive"]] <- 
  c("K-562","RPMI-8226","MDA-MB-435","MDA-MB-231/ATCC","HCC-2998",	
    "HCT-116","HCT-15","NCI-H322M","SK-MEL-28","COLO 205") ## 10 lines

cellLinesUsed[["etoposide"]][["listPotti06CorrNov07"]][["Resistant"]] <- 
  c("SF-539","BT-549","MDA-MB-231/ATCC","HCC-2998","HOP-62","NCI-H226",	
    "M14","PC-3","786-0") ## 9 lines
cellLinesUsed[["etoposide"]][["listPotti06CorrNov07"]][["Sensitive"]] <- 
  c("MCF7","NCI/ADR-RES","HCT-15","SW-620","NCI-H322M","UACC-257",
    "OVCAR-4","OVCAR-5") ## 8 lines

cellLinesUsed[["cyclophosphamide"]][["listPotti06CorrNov07"]][["Resistant"]] <- 
  c("K-562","MOLT-4","HL-60(TB)","MCF7","HCC-2998","HCT-116",
    "NCI-H460","TK-10") ## 8 lines
cellLinesUsed[["cyclophosphamide"]][["listPotti06CorrNov07"]][["Sensitive"]] <- 
  c("SNB-19","HS 578T","MDA-MB-231/ATCC","MDA-MB-435","NCI-H226","M14",
    "MALME-3M","SK-MEL-2") ## 8 lines



###################################################
### chunk number 12: checkNovAForDoce
###################################################

temp <- novartisA["36460_at",
  c("EKVX","IGROV1","OVCAR-4","786-0","CAKI-1","SN12C","TK-10",
    "HL-60(TB)","SF-539","HT29","HOP-62","SK-MEL-2","SK-MEL-5",
    "NCI-H522")]
temp
t(round(exp(scale(log(temp))),2))

rm(list=ls(pattern="^temp"))



###################################################
### chunk number 13: doceTable
###################################################
cellLinesUsed[["docetaxel"]][["doceDataPotti06CorrNov07"]][["Sensitive"]] <- 
  cellLinesUsed[["docetaxel"]][["listPotti06CorrNov07"]][["Resistant"]]
cellLinesUsed[["docetaxel"]][["doceDataPotti06CorrNov07"]][["Resistant"]] <- 
  cellLinesUsed[["docetaxel"]][["listPotti06CorrNov07"]][["Sensitive"]]


###################################################
### chunk number 14: checkNovAForAdria
###################################################

temp <- novartisA["35753_at",
  c("SF-539","SNB-75","MDA-MB-435","NCI-H23","M14",
    "MALME-3M","SK-MEL-2","SK-MEL-28","SK-MEL-5",
    "UACC-62", "NCI/ADR-RES","HCT-15","HT29","EKVX",
    "NCI-H322M","IGROV1","OVCAR-3","OVCAR-4","OVCAR-5",
    "OVCAR-8","SK-OV-3","CAKI-1")]
temp
t(round(exp(scale(log(temp))),2))
t(round(exp(scale(log(temp))),3))[1,c("OVCAR-4","SK-OV-3")]

rm(list=ls(pattern="^temp"))



###################################################
### chunk number 15: doxoTable
###################################################
cellLinesUsed[["doxorubicin"]][["doxoDataPotti06CorrNov07"]] <- 
  cellLinesUsed[["doxorubicin"]][["listPotti06CorrNov07"]]


###################################################
### chunk number 16: bonnefoiListsTake1
###################################################
tempDrugs <- c("docetaxel", "doxorubicin", "fluorouracil", 
               "cyclophosphamide")
for(tempIndex in 1:length(tempDrugs)){ 
  cellLinesUsed[[tempDrugs[tempIndex]]][["listBonnefoiDec07"]][["Sensitive"]] <- 
    cellLinesUsed[[tempDrugs[tempIndex]]][["listPotti06CorrNov07"]][["Resistant"]]
  cellLinesUsed[[tempDrugs[tempIndex]]][["listBonnefoiDec07"]][["Resistant"]] <- 
    cellLinesUsed[[tempDrugs[tempIndex]]][["listPotti06CorrNov07"]][["Sensitive"]]
}
rm(list=ls(pattern="^temp"))


###################################################
### chunk number 17: salterNumbers
###################################################
tempDrugs <- c("paclitaxel", "doxorubicin")
for(tempIndex in 1:length(tempDrugs)){ 
  cellLinesUsed[[tempDrugs[tempIndex]]][["numbersSalterApr08"]][["Sensitive"]] <- 
    cellLinesUsed[[tempDrugs[tempIndex]]][["listPotti06CorrNov07"]][["Resistant"]]
  cellLinesUsed[[tempDrugs[tempIndex]]][["numbersSalterApr08"]][["Resistant"]] <- 
    cellLinesUsed[[tempDrugs[tempIndex]]][["listPotti06CorrNov07"]][["Sensitive"]]
}
tempDrugs <- c("fluorouracil", "cyclophosphamide")
for(tempIndex in 1:length(tempDrugs)){ 
  cellLinesUsed[[tempDrugs[tempIndex]]][["numbersSalterApr08"]] <- 
    cellLinesUsed[[tempDrugs[tempIndex]]][["listPotti06CorrNov07"]]
}
rm(list=ls(pattern="^temp"))


###################################################
### chunk number 18: pottiCorr2
###################################################
tempDrugs <- c("paclitaxel", "doxorubicin", "fluorouracil",
               "topotecan", "etoposide", "cyclophosphamide")
for(tempIndex in 1:length(tempDrugs)){ 
  cellLinesUsed[[tempDrugs[tempIndex]]][["listPotti06CorrAug08"]][["Sensitive"]] <- 
    cellLinesUsed[[tempDrugs[tempIndex]]][["listPotti06CorrNov07"]][["Resistant"]]
  cellLinesUsed[[tempDrugs[tempIndex]]][["listPotti06CorrAug08"]][["Resistant"]] <- 
    cellLinesUsed[[tempDrugs[tempIndex]]][["listPotti06CorrNov07"]][["Sensitive"]]
}
tempDrugs <- c("docetaxel")
for(tempIndex in 1:length(tempDrugs)){ 
  cellLinesUsed[[tempDrugs[tempIndex]]][["listPotti06CorrAug08"]] <- 
    cellLinesUsed[[tempDrugs[tempIndex]]][["listPotti06CorrNov07"]]
}
rm(list=ls(pattern="^temp"))


###################################################
### chunk number 19: bonnefoiListsTake2
###################################################
tempDrugs <- c("docetaxel", "doxorubicin", "fluorouracil", 
               "cyclophosphamide")
for(tempIndex in 1:length(tempDrugs)){ 
  cellLinesUsed[[tempDrugs[tempIndex]]][["listBonnefoi07CorrSep08"]] <- 
    cellLinesUsed[[tempDrugs[tempIndex]]][["listPotti06CorrAug08"]]
}
rm(list=ls(pattern="^temp"))


###################################################
### chunk number 20: riedelNumbers
###################################################
tempDrugs <- 
  c("docetaxel", "paclitaxel","doxorubicin", "fluorouracil", 
    "topotecan", "etoposide", "cyclophosphamide")
for(tempIndex in 1:length(tempDrugs)){ 
  cellLinesUsed[[tempDrugs[tempIndex]]][["numbersRiedelOct08"]] <- 
    cellLinesUsed[[tempDrugs[tempIndex]]][["listPotti06CorrNov07"]]
}
rm(list=ls(pattern="^temp"))


###################################################
### chunk number 21: augustineHeatmap
###################################################
cellLinesUsed[["temozolomide"]][["heatmapAugustineJan09"]] <- 
  cellLinesUsed[["cisplatin"]][["heatmapHsuOct07"]]


###################################################
### chunk number 22: pruneBigList
###################################################
for(tempDrug in names(nscNumbers)){
  for(tempSource in informationSources){
    for(tempStatus in c("Sensitive","Resistant")){
      if(is.null(cellLinesUsed[[tempDrug]][[tempSource]][[tempStatus]])){
        cellLinesUsed[[tempDrug]][[tempSource]][[tempStatus]] <- NULL
      }
    }
    if(length(cellLinesUsed[[tempDrug]][[tempSource]]) == 0){
      cellLinesUsed[[tempDrug]][[tempSource]] <- NULL
    }
  }
  if(length(cellLinesUsed[[tempDrug]]) == 0){
    cellLinesUsed[[tempDrug]] <- NULL
  }
}
rm(list=ls(pattern="^temp"))


###################################################
### chunk number 23: buildSensitivityMatrix
###################################################

tempColumnCount <- 0
for(tempIndex in 1:length(cellLinesUsed)){
  tempColumnCount <- tempColumnCount + length(cellLinesUsed[[tempIndex]])
}

sensitivityMatrix <- 
  matrix("Not Used",nrow=length(nci60CellLines),ncol=tempColumnCount)
rownames(sensitivityMatrix) <- nci60CellLines

tempColumn <- 1
for(tempDrug in 1:length(cellLinesUsed)){
  for(tempSource in 1:length(cellLinesUsed[[tempDrug]])){

    if(all(!is.na(match(cellLinesUsed[[tempDrug]][[tempSource]][["Sensitive"]],
                        nci60CellLines)))){
      sensitivityMatrix[cellLinesUsed[[tempDrug]][[tempSource]][["Sensitive"]],
                        tempColumn] <- "Sensitive"
      sensitivityMatrix[cellLinesUsed[[tempDrug]][[tempSource]][["Resistant"]],
                        tempColumn] <- "Resistant"
    }
    tempColumn <- tempColumn + 1
  }
}

rm(list=ls(pattern="^temp"))



###################################################
### chunk number 24: buildSourceMatrix
###################################################

tempColumn <- 1
sourceMatrix <- 
  matrix(FALSE, nrow=length(informationSources), 
         ncol=dim(sensitivityMatrix)[2])
rownames(sourceMatrix) <- informationSources
for(tempDrug in 1:length(cellLinesUsed)){
  for(tempSource in 1:length(cellLinesUsed[[tempDrug]])){
    tempSourceRow <- match(names(cellLinesUsed[[tempDrug]])[tempSource],
                           informationSources)
    sourceMatrix[tempSourceRow,tempColumn] <- TRUE
    tempColumn <- tempColumn + 1
  }
}

rm(list=ls(pattern="^temp"))



###################################################
### chunk number 25: drawThePlotBlock1 eval=FALSE
###################################################
## 
## ## figure out the number of columns of information
## ## we have for each drug.
## 
## tempNDrugs <- length(cellLinesUsed)
## tempDrugCounts <- rep(0,tempNDrugs)
## for(tempDrug in 1:tempNDrugs){
##   tempDrugCounts[tempDrug] <- length(cellLinesUsed[[tempDrug]])
## }
## names(tempDrugCounts) <- names(cellLinesUsed)
## tempDrugLastIndices <- cumsum(tempDrugCounts)
## tempDrugCenters <- 
##   (c(1,tempDrugLastIndices[1:(tempNDrugs-1)]+1) +
##    tempDrugLastIndices)/2
## 
## tempShrink <- 1
## 
## 


###################################################
### chunk number 26: drawThePlotBlock2 eval=FALSE
###################################################
## ## partition the figure into panels and define colors
## 
## tempMainImageMapPanel <- c(10/46,45/46,11.5/60,55.5/60)
## tempSourceMapPanel    <- c(10/46,45/46,1.5/60,10.5/60)
## tempLegendPanel       <- c(2/46,7.5/46,56.5/60,59/60)
## 
## tempSensitiveColor <- "blue"
## tempResistantColor <- "red"
## 


###################################################
### chunk number 27: drawThePlotBlock3 eval=FALSE
###################################################
## 
## ## draw the main cell line/drug * source matrix in two
## ## stages: Sensitive, then Resistant.
## 
## par(plt=tempMainImageMapPanel)
## 
## image(1:max(tempDrugLastIndices),
##       1:length(nci60CellLines),
##       t(sensitivityMatrix=="Sensitive"),
##       xlab="",ylab="",xaxt="n",yaxt="n",
##       ylim=c(length(nci60CellLines)+0.5, 0.5),
##       col=c("transparent",tempSensitiveColor))
## 
## par(plt=tempMainImageMapPanel, new=TRUE)
## 
## image(1:max(tempDrugLastIndices),
##       1:length(nci60CellLines),
##       t(sensitivityMatrix=="Resistant"),
##       xlab="",ylab="",xaxt="n",yaxt="n",
##       ylim=c(length(nci60CellLines)+0.5, 0.5),
##       col=c("transparent",tempResistantColor))
## 
## box()
## 
## abline(v=(tempDrugLastIndices[1:(tempNDrugs-1)]+0.5))
## 
## ## add names of cell lines
## 
## tempScale = 0.75 * tempShrink
## 
## mtext(paste(nci60CellLines,c(" "),sep=""),
##       side=2,at=1:length(nci60CellLines),las=2,cex=tempScale)
## 
## ## add names of drugs. This part will require some
## ## customization to keep the drug names from overlapping.
## 
## tempDrugNames <- names(cellLinesUsed)
## tempCap <- toupper(substr(tempDrugNames,1,1))
## substr(tempDrugNames,1,1) <- tempCap
## 
## tempNameLocs <- tempDrugCenters
## #tempNameHeights <- c(0.5, 0.5, 0.5, 0.5, 0.5, 1.5, 0.5,
## #                     1.5, 2.4, 3.3)
## tempNameHeights <- c(0.3, 0.3, 0.3, 0.3, 0.3, 1.1, 0.3,
##                      1.1, 1.9, 2.7) * tempShrink
## tempNameAdj <- c(rep(0.5,7), rep(1,3))
## 
## mtext(tempDrugNames, side=3, at=tempNameLocs,
##       line=tempNameHeights, adj=tempNameAdj, cex=tempScale)
## axis(side=3,at=tempDrugCenters[8]+0.2,labels="",tcl=-1.6*tempShrink)
## axis(side=3,at=tempDrugCenters[9]+0.2,labels="",tcl=-2.4*tempShrink)
## axis(side=3,at=tempDrugCenters[10]+0.2,labels="",tcl=-3.2*tempShrink)
## 
## axis(side=2, at=(length(nci60CellLines)+1)/2,
##      labels="NCI-60 Cell Lines", line=8, tick=FALSE, cex=tempShrink)
## axis(side=3, at=(max(tempDrugLastIndices)+1)/2,
##      labels="Drug", line=1, tick=FALSE, cex=tempShrink)
## 


###################################################
### chunk number 28: drawThePlotBlock4 eval=FALSE
###################################################
## 
## ## Now shift to the information source panel.
## 
## par(plt=tempSourceMapPanel, new=TRUE)
## 
## tempSourceNames <-
##   c("Potti Heatmap, Nov 06",
##     "Hsu Heatmap, Oct 07",
##     "Potti Corr 1 Gene List, Nov 07",
##     "Potti Corr 1 Doce Data, Nov 07",
##     "Potti Corr 1 Doxo Data, Nov 07",
##     "Potti Corr 1 List, Nov 07",
##     "Bonnefoi List, Dec 07",
##     "Salter Numbers, Apr 08",
##     "Potti Corr 2 List, Aug 08",
##     "Bonnefoi Corr List, Sep 08",
##     "Riedel Numbers, Oct 08",
##     "Augustine Heatmap, Jan 09")
## 
## image(1:max(tempDrugLastIndices),
##       1:length(tempSourceNames),
##       ylim=c(length(tempSourceNames)+0.5,0.5),
##       t(sourceMatrix),xlab="",ylab="",xaxt="n",yaxt="n",
##       col=c("white","black"))
## box()
## 
## abline(v=(tempDrugLastIndices[1:(tempNDrugs-1)]+0.5))
## abline(h=c(1:length(tempSourceNames)),col="gray",lty="dashed")
## 
## mtext(paste(tempSourceNames,c(" "),sep=""),
##       side=2,at=1:length(tempSourceNames),las=2,cex=tempScale)
## axis(side=2, at=(length(tempSourceNames)+1)/2,
##      labels="Information Source", line=8,tick=FALSE, cex=tempShrink)
## 


###################################################
### chunk number 29: drawThePlotBlock5 eval=FALSE
###################################################
## 
## ## Finally, add the legend panel.
## 
## par(plt=tempLegendPanel, new=TRUE)
## 
## plot(c(0,1),c(0,1),type="n",xlab="",ylab="",xaxt="n",yaxt="n")
## legend(x="center",legend=c("Sensitive","Resistant"),
##        fill=c(tempSensitiveColor, tempResistantColor), cex=tempShrink)
## 
## rm(list=ls(pattern="^temp"))
## 


###################################################
### chunk number 30: drawThePlotReally
###################################################

pdf(file=file.path("Figures","enumeratingCellLines-heatmap.pdf"),
    width=9.3, height=10.6)
tempPar <- par(omi=c(0,0,0,0), fin=c(9.2,10.4))


## figure out the number of columns of information
## we have for each drug.

tempNDrugs <- length(cellLinesUsed)
tempDrugCounts <- rep(0,tempNDrugs)
for(tempDrug in 1:tempNDrugs){
  tempDrugCounts[tempDrug] <- length(cellLinesUsed[[tempDrug]])
}
names(tempDrugCounts) <- names(cellLinesUsed)
tempDrugLastIndices <- cumsum(tempDrugCounts)
tempDrugCenters <- 
  (c(1,tempDrugLastIndices[1:(tempNDrugs-1)]+1) +
   tempDrugLastIndices)/2

tempShrink <- 1


## partition the figure into panels and define colors

tempMainImageMapPanel <- c(10/46,45/46,11.5/60,55.5/60)
tempSourceMapPanel    <- c(10/46,45/46,1.5/60,10.5/60)
tempLegendPanel       <- c(2/46,7.5/46,56.5/60,59/60)

tempSensitiveColor <- "blue"
tempResistantColor <- "red"


## draw the main cell line/drug * source matrix in two
## stages: Sensitive, then Resistant.

par(plt=tempMainImageMapPanel)

image(1:max(tempDrugLastIndices),
      1:length(nci60CellLines),
      t(sensitivityMatrix=="Sensitive"),
      xlab="",ylab="",xaxt="n",yaxt="n",
      ylim=c(length(nci60CellLines)+0.5, 0.5),
      col=c("transparent",tempSensitiveColor))

par(plt=tempMainImageMapPanel, new=TRUE)

image(1:max(tempDrugLastIndices),
      1:length(nci60CellLines),
      t(sensitivityMatrix=="Resistant"),
      xlab="",ylab="",xaxt="n",yaxt="n",
      ylim=c(length(nci60CellLines)+0.5, 0.5),
      col=c("transparent",tempResistantColor))

box()

abline(v=(tempDrugLastIndices[1:(tempNDrugs-1)]+0.5))

## add names of cell lines

tempScale = 0.75 * tempShrink

mtext(paste(nci60CellLines,c(" "),sep=""),
      side=2,at=1:length(nci60CellLines),las=2,cex=tempScale)

## add names of drugs. This part will require some
## customization to keep the drug names from overlapping.

tempDrugNames <- names(cellLinesUsed)
tempCap <- toupper(substr(tempDrugNames,1,1))
substr(tempDrugNames,1,1) <- tempCap

tempNameLocs <- tempDrugCenters
#tempNameHeights <- c(0.5, 0.5, 0.5, 0.5, 0.5, 1.5, 0.5,
#                     1.5, 2.4, 3.3)
tempNameHeights <- c(0.3, 0.3, 0.3, 0.3, 0.3, 1.1, 0.3,
                     1.1, 1.9, 2.7) * tempShrink
tempNameAdj <- c(rep(0.5,7), rep(1,3))

mtext(tempDrugNames, side=3, at=tempNameLocs,
      line=tempNameHeights, adj=tempNameAdj, cex=tempScale)
axis(side=3,at=tempDrugCenters[8]+0.2,labels="",tcl=-1.6*tempShrink)
axis(side=3,at=tempDrugCenters[9]+0.2,labels="",tcl=-2.4*tempShrink)
axis(side=3,at=tempDrugCenters[10]+0.2,labels="",tcl=-3.2*tempShrink)

axis(side=2, at=(length(nci60CellLines)+1)/2,
     labels="NCI-60 Cell Lines", line=8, tick=FALSE, cex=tempShrink)
axis(side=3, at=(max(tempDrugLastIndices)+1)/2,
     labels="Drug", line=1, tick=FALSE, cex=tempShrink)


## Now shift to the information source panel.

par(plt=tempSourceMapPanel, new=TRUE)

tempSourceNames <-
  c("Potti Heatmap, Nov 06",
    "Hsu Heatmap, Oct 07",
    "Potti Corr 1 Gene List, Nov 07",
    "Potti Corr 1 Doce Data, Nov 07",
    "Potti Corr 1 Doxo Data, Nov 07",
    "Potti Corr 1 List, Nov 07",
    "Bonnefoi List, Dec 07",
    "Salter Numbers, Apr 08",
    "Potti Corr 2 List, Aug 08",
    "Bonnefoi Corr List, Sep 08",
    "Riedel Numbers, Oct 08",
    "Augustine Heatmap, Jan 09")

image(1:max(tempDrugLastIndices),
      1:length(tempSourceNames),
      ylim=c(length(tempSourceNames)+0.5,0.5),
      t(sourceMatrix),xlab="",ylab="",xaxt="n",yaxt="n",
      col=c("white","black"))
box()

abline(v=(tempDrugLastIndices[1:(tempNDrugs-1)]+0.5))
abline(h=c(1:length(tempSourceNames)),col="gray",lty="dashed")

mtext(paste(tempSourceNames,c(" "),sep=""),
      side=2,at=1:length(tempSourceNames),las=2,cex=tempScale)
axis(side=2, at=(length(tempSourceNames)+1)/2,
     labels="Information Source", line=8,tick=FALSE, cex=tempShrink)


## Finally, add the legend panel.

par(plt=tempLegendPanel, new=TRUE)

plot(c(0,1),c(0,1),type="n",xlab="",ylab="",xaxt="n",yaxt="n")
legend(x="center",legend=c("Sensitive","Resistant"),
       fill=c(tempSensitiveColor, tempResistantColor), cex=tempShrink)

rm(list=ls(pattern="^temp"))


dev.off()

setEPS()
postscript(file=file.path("Figures","enumeratingCellLines-heatmap.eps"),
    width=9.3, height=10.6)
tempPar <- par(omi=c(0,0,0,0), fin=c(9.2,10.4))


## figure out the number of columns of information
## we have for each drug.

tempNDrugs <- length(cellLinesUsed)
tempDrugCounts <- rep(0,tempNDrugs)
for(tempDrug in 1:tempNDrugs){
  tempDrugCounts[tempDrug] <- length(cellLinesUsed[[tempDrug]])
}
names(tempDrugCounts) <- names(cellLinesUsed)
tempDrugLastIndices <- cumsum(tempDrugCounts)
tempDrugCenters <- 
  (c(1,tempDrugLastIndices[1:(tempNDrugs-1)]+1) +
   tempDrugLastIndices)/2

tempShrink <- 1


## partition the figure into panels and define colors

tempMainImageMapPanel <- c(10/46,45/46,11.5/60,55.5/60)
tempSourceMapPanel    <- c(10/46,45/46,1.5/60,10.5/60)
tempLegendPanel       <- c(2/46,7.5/46,56.5/60,59/60)

tempSensitiveColor <- "blue"
tempResistantColor <- "red"


## draw the main cell line/drug * source matrix in two
## stages: Sensitive, then Resistant.

par(plt=tempMainImageMapPanel)

image(1:max(tempDrugLastIndices),
      1:length(nci60CellLines),
      t(sensitivityMatrix=="Sensitive"),
      xlab="",ylab="",xaxt="n",yaxt="n",
      ylim=c(length(nci60CellLines)+0.5, 0.5),
      col=c("transparent",tempSensitiveColor))

par(plt=tempMainImageMapPanel, new=TRUE)

image(1:max(tempDrugLastIndices),
      1:length(nci60CellLines),
      t(sensitivityMatrix=="Resistant"),
      xlab="",ylab="",xaxt="n",yaxt="n",
      ylim=c(length(nci60CellLines)+0.5, 0.5),
      col=c("transparent",tempResistantColor))

box()

abline(v=(tempDrugLastIndices[1:(tempNDrugs-1)]+0.5))

## add names of cell lines

tempScale = 0.75 * tempShrink

mtext(paste(nci60CellLines,c(" "),sep=""),
      side=2,at=1:length(nci60CellLines),las=2,cex=tempScale)

## add names of drugs. This part will require some
## customization to keep the drug names from overlapping.

tempDrugNames <- names(cellLinesUsed)
tempCap <- toupper(substr(tempDrugNames,1,1))
substr(tempDrugNames,1,1) <- tempCap

tempNameLocs <- tempDrugCenters
#tempNameHeights <- c(0.5, 0.5, 0.5, 0.5, 0.5, 1.5, 0.5,
#                     1.5, 2.4, 3.3)
tempNameHeights <- c(0.3, 0.3, 0.3, 0.3, 0.3, 1.1, 0.3,
                     1.1, 1.9, 2.7) * tempShrink
tempNameAdj <- c(rep(0.5,7), rep(1,3))

mtext(tempDrugNames, side=3, at=tempNameLocs,
      line=tempNameHeights, adj=tempNameAdj, cex=tempScale)
axis(side=3,at=tempDrugCenters[8]+0.2,labels="",tcl=-1.6*tempShrink)
axis(side=3,at=tempDrugCenters[9]+0.2,labels="",tcl=-2.4*tempShrink)
axis(side=3,at=tempDrugCenters[10]+0.2,labels="",tcl=-3.2*tempShrink)

axis(side=2, at=(length(nci60CellLines)+1)/2,
     labels="NCI-60 Cell Lines", line=8, tick=FALSE, cex=tempShrink)
axis(side=3, at=(max(tempDrugLastIndices)+1)/2,
     labels="Drug", line=1, tick=FALSE, cex=tempShrink)


## Now shift to the information source panel.

par(plt=tempSourceMapPanel, new=TRUE)

tempSourceNames <-
  c("Potti Heatmap, Nov 06",
    "Hsu Heatmap, Oct 07",
    "Potti Corr 1 Gene List, Nov 07",
    "Potti Corr 1 Doce Data, Nov 07",
    "Potti Corr 1 Doxo Data, Nov 07",
    "Potti Corr 1 List, Nov 07",
    "Bonnefoi List, Dec 07",
    "Salter Numbers, Apr 08",
    "Potti Corr 2 List, Aug 08",
    "Bonnefoi Corr List, Sep 08",
    "Riedel Numbers, Oct 08",
    "Augustine Heatmap, Jan 09")

image(1:max(tempDrugLastIndices),
      1:length(tempSourceNames),
      ylim=c(length(tempSourceNames)+0.5,0.5),
      t(sourceMatrix),xlab="",ylab="",xaxt="n",yaxt="n",
      col=c("white","black"))
box()

abline(v=(tempDrugLastIndices[1:(tempNDrugs-1)]+0.5))
abline(h=c(1:length(tempSourceNames)),col="gray",lty="dashed")

mtext(paste(tempSourceNames,c(" "),sep=""),
      side=2,at=1:length(tempSourceNames),las=2,cex=tempScale)
axis(side=2, at=(length(tempSourceNames)+1)/2,
     labels="Information Source", line=8,tick=FALSE, cex=tempShrink)


## Finally, add the legend panel.

par(plt=tempLegendPanel, new=TRUE)

plot(c(0,1),c(0,1),type="n",xlab="",ylab="",xaxt="n",yaxt="n")
legend(x="center",legend=c("Sensitive","Resistant"),
       fill=c(tempSensitiveColor, tempResistantColor), cex=tempShrink)

rm(list=ls(pattern="^temp"))


dev.off()



###################################################
### chunk number 31: getLocation
###################################################

getwd()



###################################################
### chunk number 32: saveStuff
###################################################

save(cellLinesUsed,
     nscNumbers,
     nci60CellLines,
     gyorffyCellLines,
     informationSources,
     sensitivityMatrix,
     sourceMatrix,
     file=file.path("RDataObjects","cellLinesUsed.Rda"))



###################################################
### chunk number 33: sessionInfo
###################################################

sessionInfo();



