###################################################
### chunk number 1: options
###################################################

options(width=80)
library(geneplotter)



###################################################
### chunk number 2: loadData
###################################################

rdaList <- c("novartisA","cellLinesUsed")
for(rdaFile in rdaList){
  rdaFullFile <- 
    file.path("RDataObjects",paste(rdaFile,"Rda",sep="."))
  if(file.exists(rdaFullFile)){
    cat("loading ",rdaFullFile, " from cache\n")
    load(rdaFullFile)
  }else{
    cat("building ",rdaFullFile, " from raw data\n")
    Stangle(file.path("RNowebSource",
                      paste("buildRda",rdaFile,"Rnw",sep=".")))
    source(paste("buildRda",rdaFile,"R",sep="."))
  }
}



###################################################
### chunk number 3: loadGenes
###################################################

doxorubicinGenes <- 
  read.table(file.path("RawData","PottiNatMed",
                       "GeneListsNov07","Adria(final).txt"),
             sep="\t",header=TRUE)
dim(doxorubicinGenes)
doxorubicinGenes[1:3,]
doxorubicinGenes <- as.character(doxorubicinGenes[,"Probe.Set.ID"])
doxorubicinGenes[1:3]



###################################################
### chunk number 4: loadDoxo07
###################################################

tempDoxorubicin07Header1 <- 
  read.table(file.path("RawData","PottiNatMed","Adria_ALL.txt"), sep="\t",
             nrows=1, header=FALSE)
tempDoxorubicin07Header1 <- as.vector(t(tempDoxorubicin07Header1));

tempDoxorubicin07Header2 <- 
  read.table(file.path("RawData","PottiNatMed","Adria_ALL.txt"), sep="\t",
             skip=1, nrows=1, header=FALSE)
tempDoxorubicin07Header2 <- as.vector(t(tempDoxorubicin07Header2));

tempDoxorubicin07Header1[1:25]
tempDoxorubicin07Header2[1:25]

table(tempDoxorubicin07Header1)
table(tempDoxorubicin07Header2)



###################################################
### chunk number 5: buildDoxo07Info
###################################################

tempSampleNames <- 
  c(paste("Training", c(1:22), sep=""), 
    paste("Test", c(1:122), sep=""))

tempGroup <- c(rep("Training", 22), rep("Test", 122))
tempStatus <- tempDoxorubicin07Header2
tempStatus[tempStatus == "Sens"] <- "Sensitive"
tempStatus[tempStatus == "NR"]   <- "Resistant"
tempStatus[tempStatus == "Resp"] <- "Sensitive"

doxorubicin07Info <- 
  data.frame(sampleGroup = tempGroup,
             status      = tempStatus,
             row.names   = tempSampleNames)

doxorubicin07Info[c(1:2,22:25),]

#rm(doxorubicin07Header1, doxorubicin07Header2, tempGroup, tempStatus)
rm(list=ls(pattern="^temp"))



###################################################
### chunk number 6: loadDoxo07Numbers
###################################################

doxorubicin07Numbers <- 
  read.table(file.path("RawData","PottiNatMed","Adria_ALL.txt"), sep="\t",
             skip=2, header=FALSE)

colnames(doxorubicin07Numbers) <- rownames(doxorubicin07Info)

doxorubicin07Numbers[1:4,c(1:2,22:25)]



###################################################
### chunk number 7: loadDoxo08
###################################################

doxorubicin08Table <- 
  read.table(file.path("RawData","PottiNatMed","Adria_ALL_data1_n95_table.csv"),
             sep=",",header=TRUE,nrows=95)
dim(doxorubicin08Table)
doxorubicin08Table[1:3,]
#doxorubicin08Table[94:96,]
#doxorubicin08Table <- doxorubicin08Table[1:95,]



###################################################
### chunk number 8: loadHollemanKey
###################################################

hollemanKeyGSM <- 
  read.table(file.path("RawData","HollemanNEJM","key_gsm.csv"),
             sep=",",header=TRUE)
dim(hollemanKeyGSM)
hollemanKeyGSM[1:4,]

hollemanKeyGSE <- 
  read.table(file.path("RawData","HollemanNEJM","key_gse.csv"),
             sep=",",header=TRUE)
dim(hollemanKeyGSE)
hollemanKeyGSE[1:3,]



###################################################
### chunk number 9: getGSE2351Clinical
###################################################

gse2351Clinical <-
  read.table(file.path("RawData","GEO","GSE2351","gse2351.csv"),
             sep=",",header=TRUE)
dim(gse2351Clinical)
gse2351Clinical[1:4,]



###################################################
### chunk number 10: getDoxoQuants
###################################################

#names(cellLinesUsed[["doxorubicin"]])
cellLinesUsed[["doxorubicin"]][["listPotti06CorrAug08"]]



###################################################
### chunk number 11: getDoxoQuants
###################################################

doxorubicinNCI60Quants <- 
  novartisA[,
            c(cellLinesUsed[["doxorubicin"]][[
                             "listPotti06CorrAug08"]][["Sensitive"]],
              cellLinesUsed[["doxorubicin"]][[
                             "listPotti06CorrAug08"]][["Resistant"]])]



###################################################
### chunk number 12: scaleDoxoData
###################################################

doxorubicinNCI60Scaled <- 
  round(exp(t(scale(t(log(doxorubicinNCI60Quants))))),2)



###################################################
### chunk number 13: checkDimensions
###################################################

dim(doxorubicin07Numbers)
dim(doxorubicinNCI60Scaled)



###################################################
### chunk number 14: matchFirstProbeset
###################################################

temp <- cor(doxorubicinNCI60Scaled[1,],
            t(doxorubicin07Numbers[,1:22]))
max(temp)
which.max(temp)



###################################################
### chunk number 15: plotFirstProbeset
###################################################

smoothScatter(1:length(temp), temp,
              xlab="Row Index in Adria_ALL.txt",
              ylab="Correlation",
              main=paste("Correlation with Scaled Values for",
                rownames(doxorubicinNCI60Scaled)[1]))
points(which.max(temp), max(temp), pch="o", col="red",cex=2)



###################################################
### chunk number 16: checkMinOfMax
###################################################

## This takes about 2.5 minutes on my MacBook Pro.

tempIndices <- apply(doxorubicin07Numbers[,1:22], 1, function(x){
  which.max(cor(x, t(doxorubicinNCI60Scaled)))
})
tempCors <- apply(cbind(doxorubicin07Numbers[,1:22], 
                        doxorubicinNCI60Scaled[tempIndices,]), 1, function(x){
                          cor(x[1:22],x[23:44])
                        })
min(tempCors)



###################################################
### chunk number 17: matchRowNames
###################################################

rownames(doxorubicin07Numbers) <- 
  rownames(doxorubicinNCI60Scaled)[tempIndices]

doxorubicin07Numbers[1:3,1:5]
doxorubicinNCI60Scaled[rownames(doxorubicin07Numbers)[1:3],1:5]

rm(list=ls(pattern="^temp"))



###################################################
### chunk number 18: whichGenesAreKept
###################################################

match(doxorubicinGenes, rownames(doxorubicin07Numbers))
sum(is.na(match(doxorubicinGenes, rownames(doxorubicin07Numbers))))
keyRows <- match(doxorubicinGenes, rownames(doxorubicin07Numbers))
keyRows <- keyRows[!is.na(keyRows)];



###################################################
### chunk number 19: getSubmatrix
###################################################

doxorubicin07Submatrix <- as.matrix(log(doxorubicin07Numbers[keyRows,23:144]))
doxorubicin07Submatrix[doxorubicin07Submatrix < -4.7] <- log(0.01)



###################################################
### chunk number 20: defineSubmatrixColors
###################################################

doxorubicin07TestColors <- rep("red", 122)
doxorubicin07TestColors[doxorubicin07Info[23:144,"status"]==
                        "Sensitive"] <- "blue"



###################################################
### chunk number 21: callToOff
###################################################

dev.off()
dev.new()



###################################################
### chunk number 22: submatrixWithBoxes
###################################################

source(file.path("Scripts","jet.colors.R"))

nSubmatrixRows <- dim(doxorubicin07Submatrix)[1]
heatmap(doxorubicin07Submatrix[nSubmatrixRows:1,],
        col=jet.colors(64),
        ColSideColors=doxorubicin07TestColors,Rowv=NA,
        xlab="Test Samples")

par(xpd=TRUE) # lets us draw lines outside the plotting region

tempBlock <- c(-0.15,0.95)

#tempBlock <- c(-12,93)
names(tempBlock) <- c("Bottom","Top")

tempBlock1 <- c(0, 0.025)
tempBlock2 <- c(0.66, 0.69)
#tempBlock1 <- c(3.9, 6.2)
#tempBlock2 <- c(66.6, 69.6)
names(tempBlock1) <- c("Left","Right")
names(tempBlock2) <- c("Left","Right")

lines(tempBlock1[c("Left","Left","Right","Right","Left")],
      tempBlock[c("Bottom","Top","Top","Bottom","Bottom")],
      col="magenta",lwd=2)
lines(tempBlock2[c("Left","Left","Right","Right","Left")],
      tempBlock[c("Bottom","Top","Top","Bottom","Bottom")],
      col="magenta",lwd=2)

par(xpd=FALSE)
dev.copy2pdf(file=file.path("Figures","doxoSubmatrixWithBoxes.pdf"))
dev.copy2eps(file=file.path("Figures","doxoSubmatrixWithBoxes.eps"))



###################################################
### chunk number 23: getDoxoCors
###################################################

doxorubicin07Cors <- cor(doxorubicin07Numbers)
sum(doxorubicin07Cors > 0.9999)
sum(diag(doxorubicin07Cors) > 0.9999)



###################################################
### chunk number 24: plotDoxoHighCors
###################################################

doxorubicin07HighCors <- (doxorubicin07Cors > 0.9999)

same07Status <- matrix(rep(doxorubicin07Info[,"status"],144),144,144)
same07Status <- (same07Status == t(same07Status))

temp07Ties <- which(doxorubicin07HighCors & same07Status, arr.ind=TRUE)
temp07Ties <- temp07Ties[temp07Ties[,1] != temp07Ties[,2],]
temp07BadTies <- which(doxorubicin07HighCors & (!same07Status), arr.ind=TRUE)

plot(1:144, 1:144, pch=".", cex=3,
     xlim=c(0.5,144.5), ylim=c(0.5,144.5), 
     xaxs="i", yaxs="i",
     xlab="Column in Adria_ALL.txt",
     ylab="Column in Adria_ALL.txt",
     main="Identical Columns in Adria_ALL.txt",
     )
points(temp07Ties[,1],temp07Ties[,2],pch=21,bg="white",lwd=1)
points(temp07BadTies[,1],temp07BadTies[,2],pch=24,bg="red",lwd=2)
abline(h=22.5, v=22.5)

abline(v=32, lty="dashed")

##oldPin <- par()$pin
##par(pin=c(min(oldPin), min(oldPin)))
##
##image(1:144, 1:144,
##      (doxorubicin07HighCors & same07Status) -
##      (doxorubicin07HighCors & (!same07Status)),
##      col=c("black","white","pink"),
##      xlab="Column in Adria_ALL.txt",
##      ylab="Column in Adria_ALL.txt",
##      main="Identical Columns in Adria_ALL.txt")
##box()
##abline(h=22.5, v=22.5)
##
##par(pin=oldPin)



###################################################
### chunk number 25: tabulateTies
###################################################

nTest07Copies <- apply(doxorubicin07HighCors[23:144,23:144],1,sum)
table(nTest07Copies)
sum(table(nTest07Copies)/c(1:4))

table(nTest07Copies, doxorubicin07Info[23:144,"status"])



###################################################
### chunk number 26: checkDoxo08Ties
###################################################

same08Name <- matrix(rep(doxorubicin08Table[,"Sample.ID"],95),95,95)
same08Name <- (same08Name == t(same08Name))

same08Status <- matrix(rep(doxorubicin08Table[,"Response"],95),95,95)
same08Status <- (same08Status == t(same08Status))

table(apply(same08Name,1,sum))
sum(table(apply(same08Name,1,sum))/c(1:2))
table(apply(same08Name & (!same08Status),1,sum))
sum(table(apply(same08Name & (!same08Status),1,sum))*c(0,0.5))



###################################################
### chunk number 27: plotDoxo08Ties
###################################################

##oldPin <- par()$pin
##par(pin=c(min(oldPin), min(oldPin)))
##
##image(1:95, 1:95,
##      (same08Name & same08Status) -
##      (same08Name & (!same08Status)),
##      col=c("black","white","pink"),
##      xlab="Row in Adria_ALL_data1_n95.doc",
##      ylab="Row in Adria_ALL_data1_n95.doc",
##      main="Identical Rows in Adria_ALL_data1_n95.doc")
##box()
##
##tempDuplicateRows <- which(duplicated(doxorubicin08Table$Sample.ID))
##
##for(tempIndex in 1:length(tempDuplicateRows)){
##
##  temp <- tempDuplicateRows[tempIndex]
##  lines(c(temp-1.5,temp+0.5,temp+0.5,temp-1.5,temp-1.5),
##        c(temp-1.5,temp-1.5,temp+0.5,temp+0.5,temp-1.5),
##        col="green")
##
##}
##
##par(pin=oldPin)

same08Name <- matrix(rep(doxorubicin08Table[,"Sample.ID"],95),95,95)
same08Name <- (same08Name == t(same08Name))

same08Status <- matrix(rep(doxorubicin08Table[,"Response"],95),95,95)
same08Status <- (same08Status == t(same08Status))

temp08Ties <- which(same08Name & same08Status, arr.ind=TRUE)
temp08Ties <- temp08Ties[temp08Ties[,1] != temp08Ties[,2],]
temp08BadTies <- which(same08Name & (!same08Status), arr.ind=TRUE)

plot(1:95, 1:95, pch=".", cex=3,
     xlim=c(0.5,95.5), ylim=c(0.5,95.5), 
     xaxs="i", yaxs="i",
     xlab="Row in Adria_ALL_data1_n95.doc",
     ylab="Row in Adria_ALL_data1_n95.doc",
     main="Identical Rows in Adria_ALL_data1_n95.doc")
points(temp08Ties[,1],temp08Ties[,2],pch=21,bg="white",lwd=1)
points(temp08BadTies[,1],temp08BadTies[,2],pch=24,bg="red",lwd=2)



###################################################
### chunk number 28: nameDuplicates
###################################################

distinct08GSMs <- 
  as.character(doxorubicin08Table$Sample.ID[
     !duplicated(doxorubicin08Table$Sample.ID)])
duplicate08GSMs <- 
  as.character(doxorubicin08Table$Sample.ID[
     duplicated(doxorubicin08Table$Sample.ID)])

duplicate08Rows <- which(same08Name & upper.tri(same08Name), arr.ind=TRUE)
duplicate08Calls <- 
  data.frame(Row1 = duplicate08Rows[,1],
             Row2 = duplicate08Rows[,2],
             Call1 = as.character(doxorubicin08Table[duplicate08Rows[,1],
               "Response"]),
             Call2 = as.character(doxorubicin08Table[duplicate08Rows[,2],
               "Response"]),
             Inconsistent = 
             (doxorubicin08Table[duplicate08Rows[,1],"Response"]) !=
             (doxorubicin08Table[duplicate08Rows[,2],"Response"]),
             row.names = as.character(doxorubicin08Table[duplicate08Rows[,2],
               "Sample.ID"]))
duplicate08Calls



###################################################
### chunk number 29: checkDiffs
###################################################

setdiff(distinct08GSMs, as.character(hollemanKeyGSM$gsm))
setdiff(distinct08GSMs, as.character(gse2351Clinical$gsm))



###################################################
### chunk number 30: checkLC50s
###################################################

gse2351Clinical[gse2351Clinical$gsm=="GSM44303",c("code","gsm","LC50.DNR")]
gse2351Clinical[gse2351Clinical$gsm=="GSM44304",c("code","gsm","LC50.DNR")]



###################################################
### chunk number 31: buildGSMTable
###################################################

gsmTable <- 
  data.frame(HollemanScore=rep(0,80),
             LC50.DNR=rep(0,80),
             PottiCall=I(rep("",80)),
             row.names=distinct08GSMs)
for(tempGSM in 1:length(distinct08GSMs)){

  tempHollemanRow <- which(hollemanKeyGSM$gsm == distinct08GSMs[tempGSM])
  if(length(tempHollemanRow) == 1){
    gsmTable[tempGSM,"HollemanScore"] <- 
      as.integer(as.character(hollemanKeyGSM$DNR.score[tempHollemanRow]))
  }

  tempGSE2351Row <- which(gse2351Clinical$gsm == distinct08GSMs[tempGSM])
  if(length(tempGSE2351Row) == 1){
    gsmTable[tempGSM,"LC50.DNR"] <- 
      gse2351Clinical[tempGSE2351Row,"LC50.DNR"]
  }

  tempPottiRow <- which(doxorubicin08Table$Sample.ID == distinct08GSMs[tempGSM])
  if(length(tempPottiRow) == 1){
    gsmTable[tempGSM,"PottiCall"] <-
      as.character(doxorubicin08Table[tempPottiRow,"Response"])
  }
  if(length(tempPottiRow) == 2){
    if(doxorubicin08Table$Response[tempPottiRow[1]] == 
       doxorubicin08Table$Response[tempPottiRow[2]]){
      gsmTable[tempGSM,"PottiCall"] <-
        as.character(doxorubicin08Table[tempPottiRow[1],"Response"])
    }
    else{
      gsmTable[tempGSM,"PottiCall"] <- "Inconsistent"
    }
  }
}

rm(list=ls(pattern="^temp"))
gsmTable$LC50.DNR[gsmTable$LC50.DNR==0] <- NA
gsmTable$HollemanScore[gsmTable$HollemanScore == 0] <- 2



###################################################
### chunk number 32: tabulateScores
###################################################

attach(gsmTable)

table(HollemanScore)
table(PottiCall)
table(PottiCall,HollemanScore)

detach(gsmTable)



###################################################
### chunk number 33: checkSummaries
###################################################

summary(gsmTable$LC50.DNR[gsmTable$PottiCall=="SEN"])
summary(gsmTable$LC50.DNR[gsmTable$PottiCall=="RES"])
summary(gsmTable$LC50.DNR[gsmTable$PottiCall=="RES"] < 0.075)
sort(gsmTable$LC50.DNR[gsmTable$PottiCall=="SEN"])
sort(gsmTable$LC50.DNR[gsmTable$PottiCall=="RES"])



###################################################
### chunk number 34: buildCombinedFigure eval=FALSE
###################################################
## 
## ## This figure requires two panels, both identifying
## ## the presence of ties in the data. 
## 
## tempDoxo07Panel <- c(0.07, 0.47, 0.08, 0.88)
## tempDoxo08Panel <- c(0.57, 0.97, 0.08, 0.88)
## 
## par(plt=tempDoxo07Panel)
## 
## same07Status <- matrix(rep(doxorubicin07Info[,"status"],144),144,144)
## same07Status <- (same07Status == t(same07Status))
## 
## temp07Ties <- which(doxorubicin07HighCors & same07Status, arr.ind=TRUE)
## temp07Ties <- temp07Ties[temp07Ties[,1] != temp07Ties[,2],]
## temp07BadTies <- which(doxorubicin07HighCors & (!same07Status), arr.ind=TRUE)
## 
## plot(1:144, 1:144, pch=".", cex=3,
##      xlim=c(0.5,144.5), ylim=c(0.5,144.5), 
##      xaxs="i", yaxs="i",
##      xlab="Column in Adria_ALL.txt",
##      ylab="Column in Adria_ALL.txt",
##      main="Identical Columns in Adria_ALL.txt",
##      )
## points(temp07Ties[,1],temp07Ties[,2],pch=21,bg="white",lwd=1)
## points(temp07BadTies[,1],temp07BadTies[,2],pch=24,bg="red",lwd=2)
## abline(h=22.5, v=22.5)
## 
## par(plt=tempDoxo08Panel, new=TRUE)
## 
## same08Name <- matrix(rep(doxorubicin08Table[,"Sample.ID"],95),95,95)
## same08Name <- (same08Name == t(same08Name))
## 
## same08Status <- matrix(rep(doxorubicin08Table[,"Response"],95),95,95)
## same08Status <- (same08Status == t(same08Status))
## 
## temp08Ties <- which(same08Name & same08Status, arr.ind=TRUE)
## temp08Ties <- temp08Ties[temp08Ties[,1] != temp08Ties[,2],]
## temp08BadTies <- which(same08Name & (!same08Status), arr.ind=TRUE)
## 
## plot(1:95, 1:95, pch=".", cex=3,
##      xlim=c(0.5,95.5), ylim=c(0.5,95.5), 
##      xaxs="i", yaxs="i",
##      xlab="Row in Adria_ALL_data1_n95.doc",
##      ylab="Row in Adria_ALL_data1_n95.doc",
##      main="Identical Rows in Adria_ALL_data1_n95.doc")
## points(temp08Ties[,1],temp08Ties[,2],pch=21,bg="white",lwd=1)
## points(temp08BadTies[,1],temp08BadTies[,2],pch=24,bg="red",lwd=2)
## 


###################################################
### chunk number 35: reallyPlotBig
###################################################

pdf(file="Figures/doxoSummary.pdf",height=6,width=12)

## This figure requires two panels, both identifying
## the presence of ties in the data. 

tempDoxo07Panel <- c(0.07, 0.47, 0.08, 0.88)
tempDoxo08Panel <- c(0.57, 0.97, 0.08, 0.88)

par(plt=tempDoxo07Panel)

same07Status <- matrix(rep(doxorubicin07Info[,"status"],144),144,144)
same07Status <- (same07Status == t(same07Status))

temp07Ties <- which(doxorubicin07HighCors & same07Status, arr.ind=TRUE)
temp07Ties <- temp07Ties[temp07Ties[,1] != temp07Ties[,2],]
temp07BadTies <- which(doxorubicin07HighCors & (!same07Status), arr.ind=TRUE)

plot(1:144, 1:144, pch=".", cex=3,
     xlim=c(0.5,144.5), ylim=c(0.5,144.5), 
     xaxs="i", yaxs="i",
     xlab="Column in Adria_ALL.txt",
     ylab="Column in Adria_ALL.txt",
     main="Identical Columns in Adria_ALL.txt",
     )
points(temp07Ties[,1],temp07Ties[,2],pch=21,bg="white",lwd=1)
points(temp07BadTies[,1],temp07BadTies[,2],pch=24,bg="red",lwd=2)
abline(h=22.5, v=22.5)

par(plt=tempDoxo08Panel, new=TRUE)

same08Name <- matrix(rep(doxorubicin08Table[,"Sample.ID"],95),95,95)
same08Name <- (same08Name == t(same08Name))

same08Status <- matrix(rep(doxorubicin08Table[,"Response"],95),95,95)
same08Status <- (same08Status == t(same08Status))

temp08Ties <- which(same08Name & same08Status, arr.ind=TRUE)
temp08Ties <- temp08Ties[temp08Ties[,1] != temp08Ties[,2],]
temp08BadTies <- which(same08Name & (!same08Status), arr.ind=TRUE)

plot(1:95, 1:95, pch=".", cex=3,
     xlim=c(0.5,95.5), ylim=c(0.5,95.5), 
     xaxs="i", yaxs="i",
     xlab="Row in Adria_ALL_data1_n95.doc",
     ylab="Row in Adria_ALL_data1_n95.doc",
     main="Identical Rows in Adria_ALL_data1_n95.doc")
points(temp08Ties[,1],temp08Ties[,2],pch=21,bg="white",lwd=1)
points(temp08BadTies[,1],temp08BadTies[,2],pch=24,bg="red",lwd=2)

dev.off()



###################################################
### chunk number 36: getLocation
###################################################

getwd()



###################################################
### chunk number 37: saveStuff
###################################################



###################################################
### chunk number 38: sessionInfo
###################################################

sessionInfo();



