###################################################
### chunk number 1: options
###################################################

options(width=80)



###################################################
### chunk number 2: loadEarlierRdas
###################################################

rdaList <- c("novartisAll","changAll")
for(rdaFile in rdaList){
  rdaFullFile <- 
    file.path("RDataObjects",paste(rdaFile,"Rda",sep="."))
  if(file.exists(rdaFullFile)){
    cat("loading ",rdaFullFile, " from cache\n")
    load(rdaFullFile)
  }else{
    cat("building ",rdaFullFile, " from raw data\n")
    Stangle(file.path("RNowebSource",
                      paste("buildRda",rdaFile,"Rnw",sep=".")))
    source(paste("buildRda",rdaFile,"R",sep="."))
  }
}



###################################################
### chunk number 3: loadAllChemo
###################################################

chemoPredictors <- 
  read.table(file.path("RawData","PottiNatMed",
                       "Chemo predictors (U-95) All - FINAL.txt"),
             header=TRUE, sep="\t", row.names=1)
dim(chemoPredictors)
chemoPredictors[1:3,1:3]



###################################################
### chunk number 4: checkDifferingProbes
###################################################

length(grep("^AFFX",rownames(novartisAll)))
length(grep("^AFFX",rownames(chemoPredictors)))
length(intersect(rownames(novartisAll),rownames(chemoPredictors)))
length(setdiff(rownames(novartisAll),rownames(chemoPredictors)))



###################################################
### chunk number 5: reviseColumnNames
###################################################

colnames(chemoPredictors)
drugBoundaries <- 
  c(1:dim(chemoPredictors)[2])[-grep("^X[01]",colnames(chemoPredictors))]
drugBoundaries
drugStarts <- drugBoundaries[seq(1,length(drugBoundaries),2)]
drugStops  <- drugBoundaries[seq(2,length(drugBoundaries),2)]
tempNames  <- colnames(chemoPredictors)
for(tempDrugIndex in 1:length(drugStarts)){
  drugPrefix <- 
    substr(tempNames[drugStarts[tempDrugIndex]],1,
           nchar(tempNames[drugStarts[tempDrugIndex]])-1)
  nZeros <- length(grep("^X0",tempNames[drugStarts[tempDrugIndex]:
                                        drugStops[tempDrugIndex]]))+1
  nOnes <- length(grep("^X1",tempNames[drugStarts[tempDrugIndex]:
                                        drugStops[tempDrugIndex]]))+1
  tempNames[drugStarts[tempDrugIndex]:drugStops[tempDrugIndex]] <-
    paste(drugPrefix,rep(c(0,1),times=c(nZeros,nOnes)),
          c(1:nZeros,1:nOnes),sep=".")
}
tempNames[1:3]
colnames(chemoPredictors) <- tempNames



###################################################
### chunk number 6: loadDocePredictor
###################################################

docetaxelPredictor <- 
  read.table(file.path("RawData","PottiNatMed",
                       "Docetaxel_Predictor__U-95_.txt"),
             header=TRUE, sep="\t", row.names=1)
dim(docetaxelPredictor)
docetaxelPredictor[1:3,1:3]
colnames(docetaxelPredictor)
all(rownames(docetaxelPredictor) == rownames(chemoPredictors))



###################################################
### chunk number 7: reviseDoceNames
###################################################

colnames(docetaxelPredictor) <- 
  paste("Doce",rep(c(0,1),times=c(7,7)),c(1:7,1:7),sep=".")



###################################################
### chunk number 8: matchFirstNovartis
###################################################

dim(novartisAll)
length(unique(novartisAll[1,]))
match(chemoPredictors[1,],novartisAll[1,])
table(is.na(match(chemoPredictors[1,],novartisAll[1,])),
      substr(colnames(chemoPredictors),1,4))



###################################################
### chunk number 9: defineChemoMapping
###################################################

chemoMapping <- matrix("",nrow=dim(chemoPredictors)[2],ncol=2)
colnames(chemoMapping) <- c("TableColumn", "MatchedSample")
chemoMapping[,"TableColumn"] <- colnames(chemoPredictors)
chemoMapping[,"MatchedSample"] <- 
  colnames(novartisAll)[match(chemoPredictors[1,],novartisAll[1,])]
allMatched <- rep(NA,dim(chemoMapping)[1])
for(tempIndex in 1:dim(chemoMapping)[1]){
  if(!is.na(chemoMapping[tempIndex,"MatchedSample"])){
    allMatched[tempIndex] <-
      all(chemoPredictors[,chemoMapping[tempIndex,"TableColumn"]] == 
          novartisAll[rownames(chemoPredictors),
                      chemoMapping[tempIndex,"MatchedSample"]])
  }
}

cbind(chemoMapping, allMatched)[!is.na(allMatched),]



###################################################
### chunk number 10: checkDoce
###################################################

match(docetaxelPredictor[1,],novartisAll[1,])
docetaxelMapping <- matrix("",nrow=dim(docetaxelPredictor)[2],ncol=2)
colnames(docetaxelMapping) <- c("TableColumn", "MatchedSample")
docetaxelMapping[,"TableColumn"] <- colnames(docetaxelPredictor)
docetaxelMapping[,"MatchedSample"] <- 
  colnames(novartisAll)[match(docetaxelPredictor[1,],novartisAll[1,])]
allDocetaxelMatched <- rep(NA,dim(docetaxelMapping)[1])
for(tempIndex in 1:dim(docetaxelMapping)[1]){
  allDocetaxelMatched[tempIndex] <-
    all(docetaxelPredictor[,docetaxelMapping[tempIndex,"TableColumn"]] == 
        novartisAll[rownames(docetaxelPredictor),
                    docetaxelMapping[tempIndex,"MatchedSample"]])
}

cbind(docetaxelMapping, allDocetaxelMatched)



###################################################
### chunk number 11: matchToChang
###################################################

which(changAll == chemoPredictors[1,"Doce.0.1"], arr.ind=TRUE)
match(chemoPredictors[1,],changAll["31307_at",])
length(grep("^AFFX",rownames(changAll)[1:67]))



###################################################
### chunk number 12: checkDoceMatch
###################################################

sum(chemoPredictors[,"Doce.0.1"]==changAll[68:12625,"N5"])
which(chemoPredictors[,"Doce.0.1"]!=changAll[68:12625,"N5"])
bottomOrder <- order(rownames(changAll)[c(12534:12558)+67])
all(chemoPredictors[12534:12558,"Doce.0.1"]==
    changAll[c((12534:12558)+67)[bottomOrder],"N5"])
sum(rownames(chemoPredictors[,"Doce.0.1"])==
    rownames(changAll[c(68:12600,c(12601:12625)[bottomOrder]),"N5"]))



###################################################
### chunk number 13: defineChemoMappingChang
###################################################

chemoMappingChang <- matrix("",nrow=dim(chemoPredictors)[2],ncol=2)
colnames(chemoMappingChang) <- c("TableColumn", "MatchedSample")
chemoMappingChang[,"TableColumn"] <- colnames(chemoPredictors)
chemoMappingChang[,"MatchedSample"] <- 
  colnames(changAll)[match(chemoPredictors[1,],changAll[68,])]
allMatchedChang <- rep(NA,dim(chemoMappingChang)[1])
for(tempIndex in 1:dim(chemoMappingChang)[1]){
  if(!is.na(chemoMappingChang[tempIndex,"MatchedSample"])){
    allMatchedChang[tempIndex] <-
      all(chemoPredictors[,chemoMappingChang[tempIndex,"TableColumn"]] == 
          changAll[c(68:12600,c(12601:12625)[bottomOrder]),
                   chemoMappingChang[tempIndex,"MatchedSample"]])
  }
}

cbind(chemoMappingChang, allMatchedChang)[!is.na(allMatchedChang),]



###################################################
### chunk number 14: mapChangUsedToGEO
###################################################

changAllInfo[chemoMappingChang[grep("^Doce",chemoMappingChang[,"TableColumn"]),
                               "MatchedSample"],1:3]
changAllInfo[c("N23","N13","N15","N14"),1:3]



###################################################
### chunk number 15: getCellLines
###################################################

cellLinesFromPredictors <- 
  matrix(vector("list",2*7),nrow=2,ncol=7)
rownames(cellLinesFromPredictors) <- c("Group0","Group1")
colnames(cellLinesFromPredictors) <- 
  c("Docetaxel","Doxorubicin","Paclitaxel","Fluorouracil",
    "Cyclophosphamide","Topotecan","Etoposide")



###################################################
### chunk number 16: fillDoce
###################################################

temp <- docetaxelMapping[grep("^Doce\\.0",docetaxelMapping[,"TableColumn"]),
                     "MatchedSample"]
cellLinesFromPredictors[["Group0","Docetaxel"]] <-
  substr(temp,1,nchar(temp)-2)
temp <- docetaxelMapping[grep("^Doce\\.1",docetaxelMapping[,"TableColumn"]),
                         "MatchedSample"]
cellLinesFromPredictors[["Group1","Docetaxel"]] <-
  substr(temp,1,nchar(temp)-2)

cellLinesFromPredictors[,"Docetaxel"]



###################################################
### chunk number 17: fillAdria
###################################################

temp <- chemoMapping[grep("^Adria\\.0",chemoMapping[,"TableColumn"]),
                     "MatchedSample"]
cellLinesFromPredictors[["Group0","Doxorubicin"]] <-
  substr(temp,1,nchar(temp)-2)
temp <- chemoMapping[grep("^Adria\\.1",chemoMapping[,"TableColumn"]),
                     "MatchedSample"]
cellLinesFromPredictors[["Group1","Doxorubicin"]] <-
  substr(temp,1,nchar(temp)-2)

cellLinesFromPredictors[,"Doxorubicin"]



###################################################
### chunk number 18: fillTaxol
###################################################

temp <- chemoMapping[grep("^Taxol\\.0",chemoMapping[,"TableColumn"]),
                     "MatchedSample"]
cellLinesFromPredictors[["Group0","Paclitaxel"]] <-
  substr(temp,1,nchar(temp)-2)
temp <- chemoMapping[grep("^Taxol\\.1",chemoMapping[,"TableColumn"]),
                     "MatchedSample"]
cellLinesFromPredictors[["Group1","Paclitaxel"]] <-
  substr(temp,1,nchar(temp)-2)

cellLinesFromPredictors[,"Paclitaxel"]



###################################################
### chunk number 19: fill5FU
###################################################

temp <- chemoMapping[grep("^X5\\.FU\\.0",chemoMapping[,"TableColumn"]),
                     "MatchedSample"]
cellLinesFromPredictors[["Group0","Fluorouracil"]] <-
  substr(temp,1,nchar(temp)-2)
temp <- chemoMapping[grep("^X5\\.FU\\.1",chemoMapping[,"TableColumn"]),
                     "MatchedSample"]
cellLinesFromPredictors[["Group1","Fluorouracil"]] <-
  substr(temp,1,nchar(temp)-2)

cellLinesFromPredictors[,"Fluorouracil"]



###################################################
### chunk number 20: fillCytox
###################################################

temp <- chemoMappingChang[grep("^Cytox\\.0",
                               chemoMappingChang[,"TableColumn"]),
                          "MatchedSample"]
cellLinesFromPredictors[["Group0","Cyclophosphamide"]] <- temp
temp <- chemoMappingChang[grep("^Cytox\\.1",
                               chemoMappingChang[,"TableColumn"]),
                          "MatchedSample"]
cellLinesFromPredictors[["Group1","Cyclophosphamide"]] <- temp

cellLinesFromPredictors[,"Cyclophosphamide"]



###################################################
### chunk number 21: fillTopotecan
###################################################

temp <- chemoMapping[grep("^Topo\\.0",chemoMapping[,"TableColumn"]),
                     "MatchedSample"]
cellLinesFromPredictors[["Group0","Topotecan"]] <-
  substr(temp,1,nchar(temp)-2)
temp <- chemoMapping[grep("^Topo\\.1",chemoMapping[,"TableColumn"]),
                     "MatchedSample"]
cellLinesFromPredictors[["Group1","Topotecan"]] <-
  substr(temp,1,nchar(temp)-2)

cellLinesFromPredictors[,"Topotecan"]



###################################################
### chunk number 22: fillEtoposide
###################################################

temp <- chemoMapping[grep("^Etopo\\.0",chemoMapping[,"TableColumn"]),
                     "MatchedSample"]
cellLinesFromPredictors[["Group0","Etoposide"]] <-
  substr(temp,1,nchar(temp)-2)
temp <- chemoMapping[grep("^Etopo\\.1",chemoMapping[,"TableColumn"]),
                     "MatchedSample"]
cellLinesFromPredictors[["Group1","Etoposide"]] <-
  substr(temp,1,nchar(temp)-2)

cellLinesFromPredictors[,"Etoposide"]



###################################################
### chunk number 23: checkTable
###################################################

cellLinesFromPredictors



###################################################
### chunk number 24: saveRda
###################################################

save(cellLinesFromPredictors,
     file=file.path("RDataObjects","cellLinesFromPredictors.Rda"))



###################################################
### chunk number 25: getLocation
###################################################

getwd()



###################################################
### chunk number 26: saveStuff
###################################################




###################################################
### chunk number 27: sessionInfo
###################################################

sessionInfo();



